@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-persist.h,v 1.15 2004/09/18 07:50:09 marco Exp $
+ *  $Id: ephy-embed-persist.h,v 1.20 2005/01/08 19:41:46 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_PERSIST_H
@@ -38,18 +38,18 @@ G_BEGIN_DECLS
 #define EPHY_IS_EMBED_PERSIST_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_EMBED_PERSIST))
 #define EPHY_EMBED_PERSIST_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_EMBED_PERSIST, EphyEmbedPersistClass))
 
-typedef struct _EphyEmbedPersistClass EphyEmbedPersistClass;
-typedef struct _EphyEmbedPersist EphyEmbedPersist;
-typedef struct EphyEmbedPersistPrivate EphyEmbedPersistPrivate;
+typedef struct _EphyEmbedPersistClass	EphyEmbedPersistClass;
+typedef struct _EphyEmbedPersist	EphyEmbedPersist;
+typedef struct _EphyEmbedPersistPrivate	EphyEmbedPersistPrivate;
 
 typedef enum
 {
-	EMBED_PERSIST_COPY_PAGE		= 1 << 0,
-	EMBED_PERSIST_MAINDOC		= 1 << 1,
-	EMBED_PERSIST_NO_VIEW		= 1 << 2,
-	EMBED_PERSIST_ASK_DESTINATION	= 1 << 3,
-	EMBED_PERSIST_DO_CONVERSION     = 1 << 4
-} EmbedPersistFlags;
+	EPHY_EMBED_PERSIST_COPY_PAGE		= 1 << 0,
+	EPHY_EMBED_PERSIST_MAINDOC		= 1 << 1,
+	EPHY_EMBED_PERSIST_NO_VIEW		= 1 << 2,
+	EPHY_EMBED_PERSIST_ASK_DESTINATION	= 1 << 3,
+	EPHY_EMBED_PERSIST_DO_CONVERSION     = 1 << 4
+} EphyEmbedPersistFlags;
 
 struct _EphyEmbedPersist
 {
@@ -74,7 +74,9 @@ struct _EphyEmbedPersistClass
 	char *	 (* to_string)	(EphyEmbedPersist *persist);
 };
 
-GType			 ephy_embed_persist_get_type	(void);
+GType			 ephy_embed_persist_flags_get_type	(void);
+
+GType			 ephy_embed_persist_get_type		(void);
 
 gboolean		 ephy_embed_persist_save		(EphyEmbedPersist *persist);
 
@@ -93,7 +95,7 @@ void			 ephy_embed_persist_set_fc_parent	(EphyEmbedPersist *persist,
 								 GtkWindow *value);
 
 void			 ephy_embed_persist_set_flags		(EphyEmbedPersist *persist,
-								 EmbedPersistFlags value);
+								 EphyEmbedPersistFlags value);
 
 void			 ephy_embed_persist_set_max_size	(EphyEmbedPersist *persist,
 								 long value);
@@ -112,7 +114,7 @@ const char 		*ephy_embed_persist_get_fc_title	(EphyEmbedPersist *persist);
 
 GtkWindow		*ephy_embed_persist_get_fc_parent	(EphyEmbedPersist *persist);
 
-EmbedPersistFlags	 ephy_embed_persist_get_flags		(EphyEmbedPersist *persist);
+EphyEmbedPersistFlags	 ephy_embed_persist_get_flags		(EphyEmbedPersist *persist);
 
 long			 ephy_embed_persist_get_max_size	(EphyEmbedPersist *persist);
 
