@@ -15,14 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-single.c,v 1.27 2004/10/23 16:46:46 chpe Exp $
+ *  $Id: ephy-embed-single.c,v 1.30 2005/01/11 19:15:26 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-embed-single.h"
+#include "ephy-embed-type-builtins.h"
 #include "ephy-marshal.h"
 
 static void ephy_embed_single_iface_init (gpointer g_class);
@@ -98,6 +97,54 @@ ephy_embed_single_iface_init (gpointer g_class)
 		      1,
 		      G_TYPE_BOOLEAN);
 
+/**
+ * EphyEmbedSingle::add-sidebar:
+ * @single:
+ * @url: The url of the sidebar to be added
+ * @title: The title of the sidebar to be added
+ *
+ * The ::add-sidebar signal is emitted when the user clicks a javascript link that
+ * requests adding a url to the sidebar.
+ **/
+	g_signal_new ("add-sidebar",
+		      EPHY_TYPE_EMBED_SINGLE,
+		      G_SIGNAL_RUN_LAST,
+		      G_STRUCT_OFFSET (EphyEmbedSingleIface, add_sidebar),
+		      g_signal_accumulator_true_handled, NULL,
+		      ephy_marshal_BOOLEAN__STRING_STRING,
+		      G_TYPE_BOOLEAN,
+		      2,
+		      G_TYPE_STRING,
+		      G_TYPE_STRING);
+
+/**
+ * EphyEmbedSingle::check_content:
+ * @single:
+ * @type: the type of content
+ * @address: the address of the content
+ * @requesting_address: the address of the requesting content (may be empty)
+ * @mime_type_guess: a guess of the mime type of the content (may be empty)
+ * @mime_type: the MIME type of the content
+ *
+ * The ::check-content signal is emitted when Epiphany loads any content from
+ * anywhere.
+ *
+ * If a connected callback returns %TRUE, the
+ * signal emission will stop, and the load be aborted.
+ **/
+	g_signal_new ("check_content",
+		      EPHY_TYPE_EMBED_SINGLE,
+		      G_SIGNAL_RUN_FIRST | G_SIGNAL_RUN_LAST,
+		      G_STRUCT_OFFSET (EphyEmbedSingleIface, check_content),
+		      g_signal_accumulator_true_handled, NULL,
+		      ephy_marshal_BOOLEAN__ENUM_STRING_STRING_STRING,
+		      G_TYPE_BOOLEAN,
+		      4,
+		      EPHY_TYPE_CONTENT_CHECK_TYPE,
+		      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
+		      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
+		      G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE);
+
 	initialised = TRUE;
 	}
 }
