@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-single.h,v 1.25 2004/08/08 11:32:18 chpe Exp $
+ *  $Id: ephy-embed-single.h,v 1.28 2005/01/11 19:15:26 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_SINGLE_H
@@ -35,6 +35,18 @@ G_BEGIN_DECLS
 typedef struct _EphyEmbedSingle		EphyEmbedSingle;
 typedef struct _EphyEmbedSingleIface	EphyEmbedSingleIface;
 
+typedef enum
+{
+	EPHY_CONTENT_CHECK_TYPE_OTHER	    = 1U,
+	EPHY_CONTENT_CHECK_TYPE_SCRIPT	    = 2U, /* Indicates an executable script (such as JavaScript) */
+	EPHY_CONTENT_CHECK_TYPE_IMAGE	    = 3U, /* Indicates an image (e.g., IMG elements) */
+	EPHY_CONTENT_CHECK_TYPE_STYLESHEET  = 4U, /* Indicates a stylesheet (e.g., STYLE elements) */
+	EPHY_CONTENT_CHECK_TYPE_OBJECT	    = 5U, /* Indicates a generic object (plugin-handled content typically falls under this category) */
+	EPHY_CONTENT_CHECK_TYPE_DOCUMENT    = 6U, /* Indicates a document at the top-level (i.e., in a browser) */
+	EPHY_CONTENT_CHECK_TYPE_SUBDOCUMENT = 7U, /* Indicates a document contained within another document (e.g., IFRAMEs, FRAMES, and OBJECTs) */
+	EPHY_CONTENT_CHECK_TYPE_REFRESH	    = 8U  /* Indicates a timed refresh */
+} EphyContentCheckType;
+
 struct _EphyEmbedSingleIface
 {
 	GTypeInterface base_iface;
@@ -48,20 +60,31 @@ struct _EphyEmbedSingleIface
 	void	 (* network_status) (EphyEmbedSingle *single,
 				     gboolean offline);
 
+
+        gboolean (* add_sidebar)    (EphyEmbedSingle *single,
+				     const char * url,
+				     const char * title);
+
+	gboolean (* check_content)  (EphyEmbedSingle *single,
+				     EphyContentCheckType type,
+				     const char *address,
+				     const char *requesting_address,
+				     const char *mime_type_guess);
 	/* Methods */
 
-	GtkWidget *	(* open_window)		(EphyEmbedSingle *single,
+	GtkWidget *	  (* open_window)	(EphyEmbedSingle *single,
 						 EphyEmbed *parent,
 						 const char *address,
 						 const char *name,
 						 const char *features);
-	void		(* clear_cache)		(EphyEmbedSingle *shell);
-	void		(* clear_auth_cache)	(EphyEmbedSingle *shell);
-	void		(* set_offline_mode)	(EphyEmbedSingle *shell,
+	void		  (* clear_cache)	(EphyEmbedSingle *shell);
+	void		  (* clear_auth_cache)	(EphyEmbedSingle *shell);
+	void		  (* set_offline_mode)	(EphyEmbedSingle *shell,
 						 gboolean offline);
-	gboolean	(* get_offline_mode)	(EphyEmbedSingle *single);
-	GList *		(* get_font_list)	(EphyEmbedSingle *shell,
+	gboolean	  (* get_offline_mode)	(EphyEmbedSingle *single);
+	GList *		  (* get_font_list)	(EphyEmbedSingle *shell,
 						 const char *langGroup);
+	GList *		  (* get_printer_list)	(EphyEmbedSingle *shell);
 };
 
 GType		ephy_embed_single_get_type		(void);
@@ -84,6 +107,8 @@ gboolean	ephy_embed_single_get_offline_mode	(EphyEmbedSingle *single);
 GList		*ephy_embed_single_get_font_list	(EphyEmbedSingle *single,
 							 const char *lang_group);
 
+GList		*ephy_embed_single_get_printer_list	(EphyEmbedSingle *single);
+
 G_END_DECLS
 
 #endif
