@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history.c,v 1.53 2004/12/02 15:16:41 chpe Exp $
+ *  $Id: ephy-history.c,v 1.54 2005/01/08 19:41:46 chpe Exp $
  */
 
 #include "config.h"
@@ -45,7 +45,7 @@
 
 #define EPHY_HISTORY_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_HISTORY, EphyHistoryPrivate))
 
-struct EphyHistoryPrivate
+struct _EphyHistoryPrivate
 {
 	char *xml_file;
 	EphyNodeDb *db;
