@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.cpp,v 1.70 2004/12/19 13:43:21 chpe Exp $
+ *  $Id: EphyBrowser.cpp,v 1.73 2005/01/05 20:09:09 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -1133,10 +1133,12 @@ EphyBrowser::ShowCertificate ()
 #endif
 }
 
-EmbedDocumentType
+EphyEmbedDocumentType
 EphyBrowser::GetDocumentType ()
 {
-  EmbedDocumentType type = EMBED_DOCUMENT_OTHER;
+  EphyEmbedDocumentType type = EPHY_EMBED_DOCUMENT_OTHER;
+
+  NS_ENSURE_TRUE (mDOMWindow, type);
 
   nsresult rv;
   nsCOMPtr<nsIDOMDocument> domDoc;
@@ -1149,15 +1151,15 @@ EphyBrowser::GetDocumentType ()
 
   if (xmlDoc)
     {
-      type = EMBED_DOCUMENT_XML;
+      type = EPHY_EMBED_DOCUMENT_XML;
     }
   else if (imgDoc)
     {
-      type = EMBED_DOCUMENT_IMAGE;
+      type = EPHY_EMBED_DOCUMENT_IMAGE;
     }
   else if (htmlDoc)
     {
-      type = EMBED_DOCUMENT_HTML;
+      type = EPHY_EMBED_DOCUMENT_HTML;
     }
 
   return type;
