@@ -16,15 +16,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: print-dialog.c,v 1.32 2004/08/29 19:42:36 chpe Exp $
+ *  $Id: print-dialog.c,v 1.38 2005/01/10 18:11:16 jframeau Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "print-dialog.h"
-#include "ephy-embed-dialog.h"
+#include "ephy-embed-single.h"
+#include "ephy-embed-shell.h"
 #include "ephy-file-chooser.h"
 #include "ephy-file-helpers.h"
 #include "ephy-stock-icons.h"
@@ -36,10 +35,13 @@
 #include <gtk/gtkdialog.h>
 #include <gtk/gtkentry.h>
 #include <gtk/gtkstock.h>
+#include <gtk/gtkcombobox.h>
+#include <gtk/gtkcellrenderertext.h>
+#include <gtk/gtkcelllayout.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <glib/gi18n.h>
 
-#define CONF_PRINT_PRINTER	"/apps/epiphany/dialogs/print_printer"
+#define CONF_PRINT_PRINTER	"/apps/epiphany/dialogs/print_printer_name"
 #define CONF_PRINT_FILE		"/apps/epiphany/dialogs/print_file"
 #define CONF_PRINT_DIR		"/apps/epiphany/directories/print_to_file"
 #define CONF_PRINT_PRINTON	"/apps/epiphany/dialogs/print_on"
@@ -72,12 +74,18 @@ enum
 	FROM_PROP
 };
 
+enum
+{
+	COL_PRINTER_DISPLAY_NAME,
+	COL_PRINTER_NAME
+};
+
 static const
 EphyDialogProperty print_props [] =
 {
 	{ "print_dialog",			NULL,			  PT_NORMAL,    0 },
 	{ "printer_radiobutton",		CONF_PRINT_PRINTON,	  PT_AUTOAPPLY, 0 },
-	{ "printer_entry",			CONF_PRINT_PRINTER,	  PT_AUTOAPPLY, 0 },
+	{ "printer_combobox",			CONF_PRINT_PRINTER,	  PT_AUTOAPPLY, G_TYPE_STRING },
 	{ "file_entry",				CONF_PRINT_FILE,	  PT_AUTOAPPLY, 0 },
 	{ "browse_button",			NULL,			  PT_NORMAL,	0 },
 	{ "all_pages_radiobutton",		CONF_PRINT_ALL_PAGES,	  PT_AUTOAPPLY, 0 },
@@ -222,6 +230,7 @@ ephy_print_get_print_info (void)
 				g_free (converted);
 			}
 		}
+		g_free (filename);
 
 		/* fallback */
 		if (fname == NULL)
@@ -232,7 +241,7 @@ ephy_print_get_print_info (void)
 		info->file = g_filename_to_utf8 (fname, -1, NULL, NULL, NULL);
 		g_free (fname);
 	}
-g_print (info->file);
+
 	info->printer = eel_gconf_get_string (print_props[PRINTER_PROP].pref);
 
 	info->pages = eel_gconf_get_integer (print_props[ALL_PAGES_PROP].pref);
@@ -356,17 +365,14 @@ ephy_print_dialog_new (GtkWidget *parent,
 		       EphyEmbed *embed)
 {
 	EphyDialog *dialog;
-	GtkWidget *window, *button;
-	GdkPixbuf *icon;
+	GtkWidget *widget;
+	GList *printers, *l;
+	GtkListStore *store;
+	GtkTreeIter iter;
+	GtkCellRenderer *renderer;
+	EphyEmbedSingle *single;
 
-	dialog =  EPHY_DIALOG (g_object_new (EPHY_TYPE_EMBED_DIALOG,
-					     "embed", embed,
-					     NULL));
-
-	if (parent != NULL)
-	{
-		g_object_set (G_OBJECT (dialog), "parent-window", parent, NULL);
-	}
+	dialog =  ephy_dialog_new_with_parent (parent);
 
 	ephy_dialog_construct (dialog, 
 			       print_props,
@@ -374,16 +380,38 @@ ephy_print_dialog_new (GtkWidget *parent,
 			       "print_dialog",
 			       NULL);
 
-	window = ephy_dialog_get_control (dialog, print_props[WINDOW_PROP].id);
-	icon = gtk_widget_render_icon (window, 
-				       GTK_STOCK_PRINT,
-				       GTK_ICON_SIZE_MENU,
-				       "print_dialog");
-	gtk_window_set_icon (GTK_WINDOW (window), icon);
-	g_object_unref (icon);
+	widget = ephy_dialog_get_control (dialog, print_props[WINDOW_PROP].id);
+	gtk_window_set_icon_name (GTK_WINDOW (widget), GTK_STOCK_PRINT);
 
-	button = ephy_dialog_get_control (dialog, print_props[BROWSE_PROP].id);
-	gtk_widget_set_sensitive (button, eel_gconf_key_is_writable (CONF_PRINT_FILE));
+	widget = ephy_dialog_get_control (dialog, print_props[BROWSE_PROP].id);
+	gtk_widget_set_sensitive (widget, eel_gconf_key_is_writable (CONF_PRINT_FILE));
+
+	widget = ephy_dialog_get_control (dialog, print_props[PRINTER_PROP].id);
+	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
+	store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING);
+
+	printers = ephy_embed_single_get_printer_list (single);
+	for (l = printers; l != NULL; l = l->next)
+	{
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (store, &iter,
+				    COL_PRINTER_DISPLAY_NAME, l->data,
+				    COL_PRINTER_NAME, l->data,
+				    -1);
+	}
+	g_list_foreach (printers, (GFunc)g_free, NULL);
+	g_list_free (printers);
+
+	gtk_combo_box_set_model (GTK_COMBO_BOX (widget), GTK_TREE_MODEL (store));
+	g_object_unref (store);
+
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (widget), renderer, TRUE);
+	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (widget), renderer,
+					"text", COL_PRINTER_DISPLAY_NAME,
+					NULL);
+	ephy_dialog_set_data_column (dialog, print_props[PRINTER_PROP].id,
+				     COL_PRINTER_NAME);
 
 	return dialog;
 }
@@ -393,7 +421,6 @@ ephy_print_setup_dialog_new (void)
 {
 	EphyDialog *dialog;
 	GtkWidget *window;
-	GdkPixbuf *icon;
 
 	dialog = EPHY_DIALOG (g_object_new (EPHY_TYPE_DIALOG, NULL));
 
@@ -407,12 +434,7 @@ ephy_print_setup_dialog_new (void)
 			      n_paper_format_enum, paper_format_enum);
 
 	window = ephy_dialog_get_control (dialog, setup_props[SETUP_WINDOW_PROP].id);
-	icon = gtk_widget_render_icon (window,
-				       STOCK_PRINT_SETUP,
-				       GTK_ICON_SIZE_MENU,
-				       "print_setup_dialog");
-	gtk_window_set_icon (GTK_WINDOW (window), icon);
-	g_object_unref (icon);
+	gtk_window_set_icon_name (GTK_WINDOW (window), STOCK_PRINT_SETUP);
 
 	return dialog;
 }
