@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-langs.c,v 1.12 2004/11/25 13:51:56 chpe Exp $
+ *  $Id: ephy-langs.c,v 1.14 2004/12/25 16:43:22 chpe Exp $
  */
 
 #include "config.h"
@@ -34,23 +34,23 @@
 
 static const EphyFontsLanguageInfo font_languages [] =
 {
-	{ N_("Arabic"),					"ar" },
-	{ N_("Baltic"),					"x-baltic" },
-	{ N_("Central European"),			"x-central-euro" },
-	{ N_("Cyrillic"),				"x-cyrillic" },
-	{ N_("Devanagari"),				"x-devanagari" },
-	{ N_("Greek"),					"el" },
-	{ N_("Hebrew"),					"he" },
-	{ N_("Japanese"),				"ja" },
-	{ N_("Korean"),					"ko" },
-	{ N_("Simplified Chinese"),			"zh-CN" },
-	{ N_("Tamil"),					"x-tamil" },
-	{ N_("Thai"),					"th" },
-	{ N_("Traditional Chinese"),			"zh-TW" },
-	{ N_("Traditional Chinese (Hong Kong)"),	"zh-HK" },
-	{ N_("Turkish"),				"tr" },
-	{ N_("Unicode"),				"x-unicode" },
-	{ N_("Western"),				"x-western" }
+	{ N_("select fonts for|Arabic"),				"ar" },
+	{ N_("select fonts for|Baltic"),				"x-baltic" },
+	{ N_("select fonts for|Central European"),			"x-central-euro" },
+	{ N_("select fonts for|Cyrillic"),				"x-cyrillic" },
+	{ N_("select fonts for|Devanagari"),				"x-devanagari" },
+	{ N_("select fonts for|Greek"),					"el" },
+	{ N_("select fonts for|Hebrew"),				"he" },
+	{ N_("select fonts for|Japanese"),				"ja" },
+	{ N_("select fonts for|Korean"),				"ko" },
+	{ N_("select fonts for|Simplified Chinese"),			"zh-CN" },
+	{ N_("select fonts for|Tamil"),					"x-tamil" },
+	{ N_("select fonts for|Thai"),					"th" },
+	{ N_("select fonts for|Traditional Chinese"),			"zh-TW" },
+	{ N_("select fonts for|Traditional Chinese (Hong Kong)"),	"zh-HK" },
+	{ N_("select fonts for|Turkish"),				"tr" },
+	{ N_("select fonts for|Unicode"),				"x-unicode" },
+	{ N_("select fonts for|Western"),				"x-western" }
 };
 static const guint n_font_languages = G_N_ELEMENTS (font_languages);
 
@@ -143,24 +143,9 @@ void
 ephy_langs_append_languages (GArray *array)
 {
 	const char * const * languages;
-	const char *system_lang;
 	char *lang;
 	int i;
 
-	/**
-	* This is a comma separated list of language ranges, as specified
-	* by RFC 2616, 14.4.
-	* Always include the basic language code last.
-	*
-	* Examples:
-	* "pt"    translation: "pt"
-	* "pt_BR" translation: "pt-br,pt"
-	* "zh_CN" translation: "zh-cn,zh"
-	* "zh_HK" translation: "zh-hk,zh" or maybe "zh-hk,zh-tw,zh"
-	*/
-	system_lang = _("system-language");
-
-	/* FIXME: use system_language when given, instead of g_get_language_names () ? */
 	languages = g_get_language_names ();
 	g_return_if_fail (languages != NULL);
 
@@ -286,7 +271,7 @@ typedef enum
 	STATE_ENTRIES,
 } ParserState;
 
-static gboolean
+static void
 load_iso_entries (int iso,
 		  GFunc read_entry_func,
 		  gpointer user_data)
@@ -358,14 +343,11 @@ out:
 	{
 		g_warning ("Failed to load ISO-%d codes from %s!\n",
 			   iso, filename);
-		return FALSE;
 	}
 
 	g_free (filename);
 
 	STOP_PROFILER ("Loading ISO codes")
-
-	return TRUE;
 }
 
 GHashTable *
