@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node.h,v 1.15 2003/12/16 17:29:40 marco Exp $
+ *  $Id: ephy-node.h,v 1.19 2005/01/08 19:41:46 chpe Exp $
  */
 
 #ifndef EPHY_NODE_H
@@ -32,16 +32,17 @@ G_BEGIN_DECLS
 
 #define EPHY_IS_NODE(o)	(o != NULL)
 
-typedef struct EphyNode EphyNode;
+typedef struct _EphyNode EphyNode;
 
 typedef enum
 {
-	EPHY_NODE_DESTROY,           /* RBNode *node */
-	EPHY_NODE_RESTORED,          /* RBNode *node */
-	EPHY_NODE_CHILD_ADDED,       /* RBNode *node, RBNode *child */
-	EPHY_NODE_CHILD_CHANGED,     /* RBNode *node, RBNode *child */
-	EPHY_NODE_CHILD_REMOVED,     /* RBNode *node, RBNode *child, guint old_index */
-	EPHY_NODE_CHILDREN_REORDERED /* RBNode *node, int *new_order */
+	EPHY_NODE_DESTROY,           /* EphyNode *node */
+	EPHY_NODE_RESTORED,          /* EphyNode *node */
+	EPHY_NODE_CHANGED,           /* EphyNode *node, guint property_id */
+	EPHY_NODE_CHILD_ADDED,       /* EphyNode *node, EphyNode *child */
+	EPHY_NODE_CHILD_CHANGED,     /* EphyNode *node, EphyNode *child, guint property_id */
+	EPHY_NODE_CHILD_REMOVED,     /* EphyNode *node, EphyNode *child, guint old_index */
+	EPHY_NODE_CHILDREN_REORDERED /* EphyNode *node, int *new_order */
 } EphyNodeSignalType;
 
 #include "ephy-node-db.h"
@@ -51,12 +52,12 @@ typedef void (*EphyNodeCallback) (EphyNode *node, ...);
 EphyNode   *ephy_node_new                   (EphyNodeDb *db);
 
 EphyNode   *ephy_node_new_with_id           (EphyNodeDb *db,
-					     gulong reserved_id);
+					     guint reserved_id);
 
 EphyNodeDb *ephy_node_get_db		    (EphyNode *node);
 
 /* unique node ID */
-long        ephy_node_get_id                (EphyNode *node);
+guint       ephy_node_get_id                (EphyNode *node);
 
 /* refcounting */
 void        ephy_node_ref                   (EphyNode *node);
@@ -68,6 +69,11 @@ int         ephy_node_signal_connect_object (EphyNode *node,
 					     EphyNodeCallback callback,
 					     GObject *object);
 
+guint       ephy_node_signal_disconnect_object (EphyNode *node,
+					     EphyNodeSignalType type,
+					     EphyNodeCallback callback,
+					     GObject *object);
+
 void        ephy_node_signal_disconnect     (EphyNode *node,
 					     int signal_id);
 
@@ -104,20 +110,16 @@ EphyNode     *ephy_node_new_from_xml        (EphyNodeDb *db,
 					     xmlNodePtr xml_node);
 
 /* DAG structure */
-void        ephy_node_add_child             (EphyNode *node,
+void          ephy_node_add_child           (EphyNode *node,
 					     EphyNode *child);
-void        ephy_node_remove_child          (EphyNode *node,
+void          ephy_node_remove_child        (EphyNode *node,
 					     EphyNode *child);
-void	    ephy_node_sort_children	    (EphyNode *node,
+void	      ephy_node_sort_children	    (EphyNode *node,
 					     GCompareFunc compare_func);
-gboolean    ephy_node_has_child             (EphyNode *node,
+gboolean      ephy_node_has_child           (EphyNode *node,
 					     EphyNode *child);
-
-void	    ephy_node_reorder_children	    (EphyNode *node,
+void	      ephy_node_reorder_children    (EphyNode *node,
 					     int *new_order);
-
-/* Note that ephy_node_get_children freezes the node; you'll have to thaw it when done.
- * This is to prevent the data getting changed from another thread. */
 GPtrArray    *ephy_node_get_children        (EphyNode *node);
 int           ephy_node_get_n_children      (EphyNode *node);
 EphyNode     *ephy_node_get_nth_child       (EphyNode *node,
