@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-stock-icons.h,v 1.12 2004/07/01 01:47:17 adamh Exp $
+ *  $Id: ephy-stock-icons.h,v 1.13 2004/09/13 10:24:56 chpe Exp $
  */
 
 #ifndef EPHY_STOCK_ICONS_H
@@ -23,8 +23,9 @@
 
 G_BEGIN_DECLS
 
-#define EPHY_STOCK_SECURE          "epiphany-secure"
-#define EPHY_STOCK_UNSECURE        "epiphany-unsecure"
+#define EPHY_ICON_SIZE_TAB_BUTTON "epiphany-icon-size-tab-button"
+
+#define EPHY_STOCK_CLOSE_TAB	   "epiphany-close-tab"
 #define EPHY_STOCK_POPUPS	   "epiphany-popup-hidden"
 #define EPHY_STOCK_HISTORY         "epiphany-history"
 #define EPHY_STOCK_BOOKMARKS       "epiphany-bookmarks"
@@ -37,6 +38,9 @@ G_BEGIN_DECLS
 #define STOCK_SEND_MAIL		   "stock_mail-send"
 #define STOCK_ADD_BOOKMARK	   "stock_add-bookmark"
 #define STOCK_PRINT_SETUP	   "stock_print-setup"
+#define STOCK_LOCK_INSECURE	   "stock_lock-open"
+#define STOCK_LOCK_SECURE	   "stock_lock"
+#define STOCK_LOCK_BROKEN	   "stock_lock-broken"
 
 void ephy_stock_icons_init (void);
 
