@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-view.c,v 1.54 2004/12/13 18:58:58 chpe Exp $
+ *  $Id: ephy-node-view.c,v 1.56 2005/01/08 19:41:46 chpe Exp $
  */
 
 #include "config.h"
@@ -44,7 +44,7 @@ static void ephy_node_view_finalize (GObject *object);
 
 #define EPHY_NODE_VIEW_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_NODE_VIEW, EphyNodeViewPrivate))
 
-struct EphyNodeViewPrivate
+struct _EphyNodeViewPrivate
 {
 	EphyNode *root;
 
@@ -1478,23 +1478,6 @@ ephy_node_view_is_target (EphyNodeView *view)
 	return gtk_widget_is_focus (GTK_WIDGET (view));
 }
 
-gboolean
-ephy_node_view_has_selection (EphyNodeView *view, gboolean *multiple)
-{
-	GtkTreeSelection *selection;
-	int rows;
-
-	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (view));
-	rows = gtk_tree_selection_count_selected_rows (selection);
-
-	if (multiple)
-	{
-		*multiple = rows > 1;
-	}
-
-	return rows > 0;
-}
-
 static gboolean
 filter_visible_func (GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
 {
