@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmark-properties.c,v 1.38 2004/11/02 20:57:33 chpe Exp $
+ *  $Id: ephy-bookmark-properties.c,v 1.39 2005/01/08 19:41:47 chpe Exp $
  */
 
 #include "config.h"
@@ -53,7 +53,7 @@ static void ephy_bookmark_properties_get_property (GObject *object,
 
 #define EPHY_BOOKMARK_PROPERTIES_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_BOOKMARK_PROPERTIES, EphyBookmarkPropertiesPrivate))
 
-struct EphyBookmarkPropertiesPrivate
+struct _EphyBookmarkPropertiesPrivate
 {
 	EphyBookmarks *bookmarks;
 	EphyNode *bookmark;
