@@ -15,12 +15,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.140 2004/07/23 10:49:39 marco Exp $
+ * $Id: ephy-bookmarks-editor.c,v 1.160 2005/01/08 19:41:47 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <gtk/gtktable.h>
 #include <gtk/gtklabel.h>
@@ -41,15 +39,15 @@
 #include <gtk/gtkclipboard.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtktreemodelsort.h>
+#include <gtk/gtkmessagedialog.h>
 #include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 #include <libgnomeui/gnome-stock-icons.h>
-#include <libgnomevfs/gnome-vfs-uri.h>
 #include <string.h>
 
 #include "ephy-bookmarks-editor.h"
-#include "ephy-bookmark-properties.h"
 #include "ephy-bookmarks-import.h"
+#include "ephy-bookmarks-export.h"
 #include "ephy-node-common.h"
 #include "ephy-node-view.h"
 #include "ephy-window.h"
@@ -116,6 +114,8 @@ static void cmd_bookmark_properties	  (GtkAction *action,
 					   EphyBookmarksEditor *editor);
 static void cmd_bookmarks_import	  (GtkAction *action,
 					   EphyBookmarksEditor *editor);
+static void cmd_bookmarks_export	  (GtkAction *action,
+					   EphyBookmarksEditor *editor);
 static void cmd_add_topic		  (GtkAction *action,
 					   EphyBookmarksEditor *editor);
 static void cmd_rename			  (GtkAction *action,
@@ -137,7 +137,7 @@ static void cmd_help_contents		  (GtkAction *action,
 
 #define CONF_BOOKMARKS_VIEW_DETAILS "/apps/epiphany/dialogs/bookmarks_view_details"
 
-struct EphyBookmarksEditorPrivate
+struct _EphyBookmarksEditorPrivate
 {
 	EphyBookmarks *bookmarks;
 	GtkWidget *bm_view;
@@ -150,7 +150,6 @@ struct EphyBookmarksEditorPrivate
 	GtkActionGroup *action_group;
 	int priority_col;
 	EphyBookmarksBarModel *tb_model;
-	GHashTable *props_dialogs;
 
 	GtkTreeViewColumn *title_col;
 	GtkTreeViewColumn *address_col;
@@ -179,7 +178,7 @@ static GtkActionEntry ephy_bookmark_popup_entries [] = {
 	{ "OpenInWindow", GTK_STOCK_OPEN, N_("_Open in New Window"), "<control>O",
 	  N_("Open the selected bookmark in a new window"), 
 	  G_CALLBACK (cmd_open_bookmarks_in_browser) },
-	{ "OpenInTab", NULL, N_("Open in New _Tab"), "<shift><control>O",
+	{ "OpenInTab", STOCK_NEW_TAB, N_("Open in New _Tab"), "<shift><control>O",
 	  N_("Open the selected bookmark in a new tab"), 
 	  G_CALLBACK (cmd_open_bookmarks_in_tabs) },
 	{ "Rename", NULL, N_("_Rename..."), "F2",
@@ -193,6 +192,9 @@ static GtkActionEntry ephy_bookmark_popup_entries [] = {
 	{ "Import", NULL, N_("_Import Bookmarks..."), NULL,
 	  N_("Import bookmarks from another browser or a bookmarks file"), 
 	  G_CALLBACK (cmd_bookmarks_import) },
+	{ "Export", NULL, N_("_Export Bookmarks..."), NULL,
+	  N_("Export bookmarks to a file"), 
+	  G_CALLBACK (cmd_bookmarks_export) },	  
 	{ "Close", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
 	  N_("Close the bookmarks window"), 
 	  G_CALLBACK (cmd_close) },
@@ -451,6 +453,32 @@ cmd_open_bookmarks_in_browser (GtkAction *action,
 	g_list_free (selection);
 }
 
+static GtkWidget*
+delete_topic_dialog_construct (GtkWindow *parent,
+			       const char *topic)
+{
+	GtkWidget *dialog;
+	
+	dialog = gtk_message_dialog_new (GTK_WINDOW (parent),
+					 GTK_DIALOG_MODAL,
+					 GTK_MESSAGE_WARNING,
+					 GTK_BUTTONS_CANCEL,
+					 _("Delete topic \"%s\"?"),
+					 topic);
+	
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Delete this topic?"));
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+			_("Deleting this topic will cause all its bookmarks to become "
+			"uncategorized, unless they also belong to other topics. "
+			"The bookmarks will not be deleted."));
+	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Delete Topic"), GTK_RESPONSE_ACCEPT);
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
+
+	gtk_window_group_add_window (GTK_WINDOW (parent)->group, GTK_WINDOW (dialog));
+
+        return dialog;
+}
+
 static void
 cmd_delete (GtkAction *action,
 	    EphyBookmarksEditor *editor)
@@ -473,38 +501,43 @@ cmd_delete (GtkAction *action,
 
 		if (priority == EPHY_NODE_NORMAL_PRIORITY)
 		{
-			ephy_node_view_remove (EPHY_NODE_VIEW (editor->priv->key_view));
+			GtkWidget *dialog;
+			const char *title;
+			int response;
+			GPtrArray *children;
+			
+			children = ephy_node_get_children(node);
+			
+			/* Do not warn if the topic is empty */
+			if (children->len == 0)
+			{
+				ephy_node_view_remove (EPHY_NODE_VIEW (editor->priv->key_view));
+			}
+			else
+			{
+				title = ephy_node_get_property_string (node, EPHY_NODE_KEYWORD_PROP_NAME);
+				dialog = delete_topic_dialog_construct (GTK_WINDOW (editor), title);
+				
+				response = gtk_dialog_run (GTK_DIALOG (dialog));
+
+				gtk_widget_destroy (dialog);
+
+				if (response == GTK_RESPONSE_ACCEPT)
+				{
+					ephy_node_view_remove (EPHY_NODE_VIEW (editor->priv->key_view));
+				}
+			}
 		}
 		g_list_free (selected);
 	}
 }
 
 static void
-prop_dialog_destroy_cb (GtkWidget *dialog, EphyBookmarksEditor *editor)
+show_properties_dialog (EphyBookmarksEditor *editor,
+			EphyNode *bookmark)
 {
-	EphyNode *node;
-
-	node = ephy_bookmark_properties_get_node (EPHY_BOOKMARK_PROPERTIES (dialog));
-	g_hash_table_remove (editor->priv->props_dialogs, node);
-}
-
-static void
-show_properties_dialog (EphyBookmarksEditor *editor, EphyNode *node)
-{
-	GtkWidget *dialog;
-
-	dialog = g_hash_table_lookup (editor->priv->props_dialogs, node);
-
-	if (!dialog)
-	{
-		dialog = ephy_bookmark_properties_new
-			(editor->priv->bookmarks, node, GTK_WINDOW (editor));
-		g_signal_connect (dialog, "destroy",
-				  G_CALLBACK (prop_dialog_destroy_cb), editor);
-		g_hash_table_insert (editor->priv->props_dialogs, node, dialog);
-	}
-
-	gtk_window_present (GTK_WINDOW (dialog));
+	ephy_bookmarks_show_bookmark_properties
+		(editor->priv->bookmarks, bookmark, GTK_WIDGET (editor));
 }
 
 static void
@@ -595,7 +628,7 @@ import_dialog_response_cb (GtkDialog *dialog, gint response,
 
 			ephy_file_chooser_add_mime_filter
 				(dialog, _("Epiphany bookmarks"),
-				 "text/rdf", NULL);
+				 "text/rdf", "application/rdf+xml", NULL);
 
 			filter = ephy_file_chooser_add_pattern_filter (dialog,
 							      _("All files"),
@@ -620,6 +653,88 @@ import_dialog_response_cb (GtkDialog *dialog, gint response,
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 }
 
+static void
+cmd_bookmarks_export (GtkAction *action,
+		      EphyBookmarksEditor *editor)
+{
+	GtkWidget *dialog, *hbox, *label, *combo;
+	char *filename = NULL;
+	int response, format;
+
+	dialog = GTK_WIDGET (ephy_file_chooser_new (_("Export Bookmarks"),
+		GTK_WIDGET (editor),
+		GTK_FILE_CHOOSER_ACTION_SAVE,
+		NULL,
+		EPHY_FILE_FILTER_NONE));
+
+	gtk_file_chooser_set_current_folder
+		(GTK_FILE_CHOOSER (dialog), g_get_home_dir ());
+
+	gtk_file_chooser_set_current_name
+		(GTK_FILE_CHOOSER (dialog), _("Bookmarks"));
+
+	/* Make a format selection combo & label */
+	label = gtk_label_new (_("File format:"));
+
+	combo = gtk_combo_box_new_text ();
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Epiphany (RDF)"));
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Mozilla (HTML)"));
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 1);
+	
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_box_pack_end (GTK_BOX (hbox), combo, TRUE, TRUE, 0);
+	gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	gtk_widget_show_all (hbox);
+	
+	gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (dialog), hbox);
+
+	gtk_window_group_add_window (GTK_WINDOW (editor)->group, GTK_WINDOW (dialog));
+
+	do
+	{
+		char *basename, *strtmp;
+
+		g_free (filename);
+
+		response = gtk_dialog_run (GTK_DIALOG (dialog));
+
+		format = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+		basename = g_path_get_basename (filename);
+		if (basename != NULL && strchr (basename, '.') == NULL)
+		{
+			strtmp = filename;
+			if (format == 0)
+			{
+				filename = g_strconcat (filename, ".rdf", NULL);
+			}
+			else if (format == 1)
+			{
+				filename = g_strconcat (filename, ".html", NULL);
+			}
+			g_free (strtmp);
+		}
+		g_free (basename);
+	}
+	while (response == GTK_RESPONSE_ACCEPT
+	       && !ephy_gui_confirm_overwrite_file (GTK_WIDGET (dialog), filename));
+
+	gtk_widget_destroy (dialog);
+
+	/* 0 for ephy RDF format, 1 for mozilla HTML format */
+
+	if (format == 0)
+	{
+		ephy_bookmarks_export_rdf (editor->priv->bookmarks, filename);
+	}
+	else if (format == 1)
+	{
+		ephy_bookmarks_export_mozilla (editor->priv->bookmarks, filename);
+	}
+
+	g_free (filename);
+}
+
 static void
 cmd_bookmarks_import (GtkAction *action,
 		      EphyBookmarksEditor *editor)
@@ -661,21 +776,6 @@ cmd_bookmarks_import (GtkAction *action,
 
         store = GTK_LIST_STORE (gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING));
 
-	sortmodel = gtk_tree_model_sort_new_with_model (GTK_TREE_MODEL (store));
-	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (sortmodel), 0, GTK_SORT_ASCENDING);
-
-	combo = gtk_combo_box_new ();
-	gtk_combo_box_set_model(GTK_COMBO_BOX (combo), sortmodel);
-	gtk_widget_show (combo);
-	g_object_set_data (G_OBJECT (dialog), "combo_box", combo);
-	g_object_unref (store);
-
-	cell = gtk_cell_renderer_text_new ();
-	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), cell, TRUE);
-	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), cell,
-                                        "text", 0,
-                                        NULL);
-
 	add_bookmarks_source (store, _("Firebird"),
 			      FIREBIRD_BOOKMARKS_DIR, "bookmarks.html", 4);
 	add_bookmarks_source (store, _("Firefox"),
@@ -690,9 +790,27 @@ cmd_bookmarks_import (GtkAction *action,
 	gtk_list_store_append (store, &iter);
 	gtk_list_store_set (store, &iter, 0, _("File"), 1, NULL, -1);
 
+        sortmodel = gtk_tree_model_sort_new_with_model (GTK_TREE_MODEL (store));
+        g_object_unref (store);
+
+	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (sortmodel), 0, GTK_SORT_ASCENDING);
+
+	combo = gtk_combo_box_new ();
+	gtk_combo_box_set_model(GTK_COMBO_BOX (combo), sortmodel);
+	g_object_set_data (G_OBJECT (dialog), "combo_box", combo);
+	g_object_unref (sortmodel);
+
+	cell = gtk_cell_renderer_text_new ();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), cell, TRUE);
+	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), cell,
+					"text", 0,
+					NULL);
+
 	gtk_box_pack_start (GTK_BOX (vbox), combo, TRUE, TRUE, 0);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 
+	gtk_widget_show (combo);
+
 	g_signal_connect (dialog, "response",
 			  G_CALLBACK (import_dialog_response_cb),
 			  editor);
@@ -847,9 +965,9 @@ cmd_view_columns (GtkAction *action,
 GType
 ephy_bookmarks_editor_get_type (void)
 {
-	static GType ephy_bookmarks_editor_type = 0;
+	static GType type = 0;
 
-	if (ephy_bookmarks_editor_type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo our_info =
 		{
@@ -864,12 +982,12 @@ ephy_bookmarks_editor_get_type (void)
 			(GInstanceInitFunc) ephy_bookmarks_editor_init
 		};
 
-		ephy_bookmarks_editor_type = g_type_register_static (GTK_TYPE_WINDOW,
-							             "EphyBookmarksEditor",
-							             &our_info, 0);
+		type = g_type_register_static (GTK_TYPE_WINDOW,
+					       "EphyBookmarksEditor",
+					       &our_info, 0);
 	}
 
-	return ephy_bookmarks_editor_type;
+	return type;
 }
 
 static void
@@ -926,8 +1044,6 @@ ephy_bookmarks_editor_finalize (GObject *object)
                          (gpointer *)&editor->priv->window);
 	}
 
-	g_hash_table_destroy (editor->priv->props_dialogs);
-
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -953,15 +1069,15 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 		 rename, delete, properties;
 	const gchar *open_in_window_label, *open_in_tab_label, *copy_label;
 	gboolean bmk_focus, key_focus;
-	gboolean key_selection, bmk_selection;
+	gboolean key_selection, bmk_selection, single_bmk_selected;
 	gboolean key_normal = FALSE;
-	gboolean bmk_multiple_selection;
 	gboolean cut, copy, paste, select_all;
 	gboolean can_show_in_bookmarks_bar, show_in_bookmarks_bar = FALSE;
 	GtkActionGroup *action_group;
 	GtkAction *action;
 	GList *selected;
 	GtkWidget *focus_widget;
+	int num_bmk_selected;
 
 	LOG ("Update menu sensitivity")
 
@@ -970,11 +1086,14 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 	key_focus = ephy_node_view_is_target
 		(EPHY_NODE_VIEW (editor->priv->key_view));
 	focus_widget = gtk_window_get_focus (GTK_WINDOW (editor));
-	bmk_selection = ephy_node_view_has_selection
-		(EPHY_NODE_VIEW (editor->priv->bm_view),
-		 &bmk_multiple_selection);
-	key_selection = ephy_node_view_has_selection
-		(EPHY_NODE_VIEW (editor->priv->key_view), NULL);
+
+	num_bmk_selected = gtk_tree_selection_count_selected_rows
+		 (gtk_tree_view_get_selection (GTK_TREE_VIEW (editor->priv->bm_view)));
+	bmk_selection = num_bmk_selected > 0;
+	single_bmk_selected = num_bmk_selected == 1;
+
+	key_selection = gtk_tree_selection_count_selected_rows
+		 (gtk_tree_view_get_selection (GTK_TREE_VIEW (editor->priv->key_view))) > 0;
 
 	if (GTK_IS_EDITABLE (focus_widget))
 	{
@@ -991,7 +1110,7 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 	else
 	{
 		cut = FALSE;
-		copy = (bmk_focus && !bmk_multiple_selection && bmk_selection);
+		copy = (bmk_focus && single_bmk_selected);
 		paste = FALSE;
 		select_all = bmk_focus;
 	}
@@ -1030,16 +1149,12 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 		g_list_free (selected);
 	}
 
-	if (bmk_multiple_selection)
-	{
-		open_in_window_label = N_("_Open in New Windows");
-		open_in_tab_label = N_("Open in New _Tabs");
-	}
-	else
-	{
-		open_in_window_label = _("_Open in New Window");
-		open_in_tab_label = _("Open in New _Tab");
-	}
+	open_in_window_label = ngettext ("_Open in New Window",
+					 "_Open in New Windows",
+					 num_bmk_selected);
+	open_in_tab_label = ngettext ("Open in New _Tab",
+				      "Open in New _Tabs",
+				      num_bmk_selected);
 
 	if (bmk_focus)
 	{
@@ -1052,21 +1167,21 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 
 	open_in_window = (bmk_focus && bmk_selection);
 	open_in_tab = (bmk_focus && bmk_selection);
-	rename = (bmk_focus && bmk_selection && !bmk_multiple_selection) ||
+	rename = (bmk_focus && single_bmk_selected) ||
 		 (key_selection && key_focus && key_normal);
 	delete = (bmk_focus && bmk_selection) ||
 		 (key_selection && key_focus && key_normal);
-	properties = (bmk_focus && bmk_selection && !bmk_multiple_selection);
-	can_show_in_bookmarks_bar = (bmk_focus && bmk_selection && !bmk_multiple_selection) ||
+	properties = (bmk_focus && single_bmk_selected);
+	can_show_in_bookmarks_bar = (bmk_focus && single_bmk_selected) ||
 		 (key_selection && key_focus);
 
 	action_group = editor->priv->action_group;
 	action = gtk_action_group_get_action (action_group, "OpenInWindow");
-	g_object_set (action, "sensitive", open_in_window, NULL);
-	g_object_set (action, "label", open_in_window_label, NULL);
+	g_object_set (action, "sensitive", open_in_window,
+			      "label", open_in_window_label, NULL);
 	action = gtk_action_group_get_action (action_group, "OpenInTab");
-	g_object_set (action, "sensitive", open_in_tab, NULL);
-	g_object_set (action, "label", open_in_tab_label, NULL);
+	g_object_set (action, "sensitive", open_in_tab,
+			      "label", open_in_tab_label, NULL);
 	action = gtk_action_group_get_action (action_group, "Rename");
 	g_object_set (action, "sensitive", rename, NULL);
 	action = gtk_action_group_get_action (action_group, "Delete");
@@ -1076,8 +1191,8 @@ ephy_bookmarks_editor_update_menu (EphyBookmarksEditor *editor)
 	action = gtk_action_group_get_action (action_group, "Cut");
 	g_object_set (action, "sensitive", cut, NULL);
 	action = gtk_action_group_get_action (action_group, "Copy");
-	g_object_set (action, "sensitive", copy, NULL);
-	g_object_set (action, "label", copy_label, NULL);
+	g_object_set (action, "sensitive", copy,
+			      "label", copy_label, NULL);
 	action = gtk_action_group_get_action (action_group, "Paste");
 	g_object_set (action, "sensitive", paste, NULL);
 	action = gtk_action_group_get_action (action_group, "SelectAll");
@@ -1127,7 +1242,7 @@ remove_focus_monitor (EphyBookmarksEditor *editor, GtkWidget *widget)
                                              editor);
 }
 
-static void
+static gboolean
 ephy_bookmarks_editor_show_popup_cb (GtkWidget *view,
 				     EphyBookmarksEditor *editor)
 {
@@ -1135,8 +1250,9 @@ ephy_bookmarks_editor_show_popup_cb (GtkWidget *view,
 
 	widget = gtk_ui_manager_get_widget (editor->priv->ui_merge,
 					    "/EphyBookmarkEditorPopup");
-	gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 2,
-			gtk_get_current_event_time ());
+	ephy_node_view_popup (EPHY_NODE_VIEW (view), widget);
+
+	return TRUE;
 }
 
 static void
@@ -1150,8 +1266,6 @@ ephy_bookmarks_editor_dispose (GObject *object)
 
 	editor = EPHY_BOOKMARKS_EDITOR (object);
 
-	g_return_if_fail (editor->priv != NULL);
-
 	if (editor->priv->key_view != NULL)
 	{
 		remove_focus_monitor (editor, editor->priv->key_view);
@@ -1219,15 +1333,16 @@ keyword_node_selected_cb (EphyNodeView *view,
 	}
 }
 
-static void
+static gboolean
 keyword_node_show_popup_cb (GtkWidget *view, EphyBookmarksEditor *editor)
 {
 	GtkWidget *widget;
 
 	widget = gtk_ui_manager_get_widget (editor->priv->ui_merge,
 					   "/EphyBookmarkKeywordPopup");
-	gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 2,
-			gtk_get_current_event_time ());
+	ephy_node_view_popup (EPHY_NODE_VIEW (view), widget);
+
+	return TRUE;
 }
 
 static void
@@ -1315,17 +1430,19 @@ delete_event_cb (EphyBookmarksEditor *editor)
 }
 
 static void
-node_dropped_cb (EphyNodeView *view, EphyNode *node,
-		 GList *nodes, EphyBookmarksEditor *editor)
+node_dropped_cb (EphyNodeView *view,
+		 EphyNode *node,
+		 const char * const *uris,
+		 EphyBookmarksEditor *editor)
 {
-	GList *l;
+	EphyNode *bmk;
+	int i;
 
-	for (l = nodes; l != NULL; l = l->next)
+	g_return_if_fail (uris != NULL);
+
+	for (i = 0; uris[i] != NULL; i++)
 	{
-		const char *url = (const char *) l->data;
-		EphyNode *bmk;
-
-		bmk = ephy_bookmarks_find_bookmark (editor->priv->bookmarks, url);
+		bmk = ephy_bookmarks_find_bookmark (editor->priv->bookmarks, uris[i]);
 
 		if (bmk != NULL)
 		{
@@ -1411,16 +1528,12 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 	EphyNode *node;
 	GtkUIManager *ui_merge;
 	GtkActionGroup *action_group;
-	GdkPixbuf *icon;
 	int col_id, details_value;
 
-	gtk_window_set_title (GTK_WINDOW (editor), _("Bookmarks"));
+	ephy_gui_ensure_window_group (GTK_WINDOW (editor));
 
-	icon = gtk_widget_render_icon (GTK_WIDGET (editor), 
-				       EPHY_STOCK_BOOKMARKS,
-				       GTK_ICON_SIZE_MENU,
-				       NULL);
-	gtk_window_set_icon (GTK_WINDOW(editor), icon);
+	gtk_window_set_title (GTK_WINDOW (editor), _("Bookmarks"));
+	gtk_window_set_icon_name (GTK_WINDOW (editor), EPHY_STOCK_BOOKMARKS);
 
 	g_signal_connect (editor, "delete_event",
 			  G_CALLBACK (delete_event_cb), NULL);
@@ -1524,7 +1637,7 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 			  G_CALLBACK (node_dropped_cb),
 			  editor);
 	g_signal_connect (G_OBJECT (key_view),
-			  "show_popup",
+			  "popup_menu",
 			  G_CALLBACK (keyword_node_show_popup_cb),
 			  editor);
 
@@ -1585,7 +1698,7 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 			  G_CALLBACK (ephy_bookmarks_editor_node_activated_cb),
 			  editor);
 	g_signal_connect (G_OBJECT (bm_view),
-			  "show_popup",
+			  "popup_menu",
 			  G_CALLBACK (ephy_bookmarks_editor_show_popup_cb),
 			  editor);
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (bm_view));
@@ -1596,7 +1709,7 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 
 	ephy_state_add_window (GTK_WIDGET(editor),
 			       "bookmarks_editor",
-		               450, 400,
+		               450, 400, FALSE,
 			       EPHY_STATE_WINDOW_SAVE_SIZE | EPHY_STATE_WINDOW_SAVE_POSITION);
 	ephy_state_add_paned  (GTK_WIDGET (hpaned),
 			       "bookmarks_paned",
@@ -1684,8 +1797,6 @@ ephy_bookmarks_editor_init (EphyBookmarksEditor *editor)
 {
 	editor->priv = EPHY_BOOKMARKS_EDITOR_GET_PRIVATE (editor);
 
-	editor->priv->props_dialogs = g_hash_table_new (g_direct_hash,
-                                                        g_direct_equal);
 	editor->priv->tb_model = EPHY_BOOKMARKSBAR_MODEL
 		(ephy_bookmarks_get_toolbars_model
 			(ephy_shell_get_bookmarks (ephy_shell)));
