@@ -1,5 +1,6 @@
 /*
  *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,32 +16,40 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topic-action.c,v 1.52.4.2 2004/09/27 18:11:40 chpe Exp $
+ *  $Id: ephy-topic-action.c,v 1.66 2005/01/04 21:42:58 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
-
-#include <gtk/gtktoolitem.h>
-#include <glib/gi18n.h>
-#include <libgnomevfs/gnome-vfs-uri.h>
-#include <string.h>
 
 #include "ephy-topic-action.h"
 #include "ephy-node-common.h"
 #include "ephy-bookmarks.h"
 #include "ephy-bookmarksbar.h"
+#include "ephy-link.h"
 #include "ephy-favicon-cache.h"
 #include "ephy-shell.h"
-#include "ephy-debug.h"
 #include "ephy-dnd.h"
 #include "ephy-gui.h"
-#include "ephy-string.h"
-#include "ephy-marshal.h"
+#include "ephy-debug.h"
 
-static void ephy_topic_action_init       (EphyTopicAction *action);
-static void ephy_topic_action_class_init (EphyTopicActionClass *class);
+#include <glib/gi18n.h>
+#include <gtk/gtkwidget.h>
+#include <gtk/gtkarrow.h>
+#include <gtk/gtkhbox.h>
+#include <gtk/gtklabel.h>
+#include <gtk/gtkbutton.h>
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtkstock.h>
+#include <gtk/gtkimage.h>
+#include <gtk/gtkmenuitem.h>
+#include <gtk/gtkimagemenuitem.h>
+#include <gtk/gtkseparatormenuitem.h>
+#include <gtk/gtkmain.h>
+#include <libgnomevfs/gnome-vfs-uri.h>
+#include <string.h>
+
+#define TOOLITEM_WIDTH_CHARS	24
+#define MENUITEM_WIDTH_CHARS	32
 
 #define EPHY_TOPIC_ACTION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TOPIC_ACTION, EphyTopicActionPrivate))
 
@@ -50,9 +59,8 @@ static GtkTargetEntry drag_targets[] =
 };
 static int n_drag_targets = G_N_ELEMENTS (drag_targets);
 
-struct EphyTopicActionPrivate
+struct _EphyTopicActionPrivate
 {
-	guint topic_id;
 	EphyNode *topic_node;
 
 	guint motion_handler;
@@ -64,27 +72,20 @@ struct EphyTopicActionPrivate
 enum
 {
 	PROP_0,
-	PROP_TOPIC_ID
+	PROP_TOPIC
 };
 
-enum
-{
-	OPEN,
-	OPEN_IN_TAB,
-	OPEN_IN_TABS,
-	LAST_SIGNAL
-};
+static void ephy_topic_action_class_init (EphyTopicActionClass *class);
+static void ephy_topic_action_init       (EphyTopicAction *action);
 
 static GObjectClass *parent_class = NULL;
 
-static guint ephy_topic_action_signals[LAST_SIGNAL] = { 0 };
-
 GType
 ephy_topic_action_get_type (void)
 {
 	static GType type = 0;
 
-	if (!type)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo type_info =
 		{
@@ -99,10 +100,11 @@ ephy_topic_action_get_type (void)
 			(GInstanceInitFunc) ephy_topic_action_init,
 		};
 
-		type = g_type_register_static (GTK_TYPE_ACTION,
+		type = g_type_register_static (EPHY_TYPE_LINK_ACTION,
 					       "EphyTopicAction",
 					       &type_info, 0);
 	}
+
 	return type;
 }
 
@@ -124,6 +126,7 @@ create_tool_item (GtkAction *action)
 	button = gtk_toggle_button_new ();
 	gtk_widget_add_events (GTK_WIDGET (button), GDK_BUTTON1_MOTION_MASK);
 	gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
+	gtk_button_set_focus_on_click (GTK_BUTTON (button), FALSE);
 	gtk_widget_show (button);
 	gtk_container_add (GTK_CONTAINER (hbox), button);
 	g_object_set_data (G_OBJECT (item), "button", button);
@@ -136,6 +139,8 @@ create_tool_item (GtkAction *action)
 	gtk_container_add (GTK_CONTAINER (button), hbox);
 
 	label = gtk_label_new (NULL);
+	gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
+	gtk_label_set_max_width_chars (GTK_LABEL (label), TOOLITEM_WIDTH_CHARS);
 	gtk_widget_show (label);
 	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (hbox), arrow, TRUE, TRUE, 0);
@@ -162,52 +167,37 @@ menu_activate_cb (GtkWidget *item, GtkAction *action)
 	location = ephy_node_get_property_string
 		(node, EPHY_NODE_BMK_PROP_LOCATION);
 
-	if (ephy_gui_is_middle_click ())
-	{
-		g_signal_emit (action, ephy_topic_action_signals[OPEN_IN_TAB],
-			       0, location, FALSE);
-	}
-	else
-	{
-		g_signal_emit (action, ephy_topic_action_signals[OPEN],
-			       0, location);
-	}
+	ephy_link_open (EPHY_LINK (action), location, NULL,
+			ephy_gui_is_middle_click () ? EPHY_LINK_NEW_TAB : 0);
 }
 
 static void
-ephy_topic_action_sync_label (GtkAction *action, GParamSpec *pspec, GtkWidget *proxy)
+ephy_topic_action_sync_label (GtkAction *gaction,
+			      GParamSpec *pspec,
+			      GtkWidget *proxy)
 {
-	GtkWidget *label = NULL;
-	GValue value = { 0, };
-	const char *label_text;
+	EphyTopicAction *action = EPHY_TOPIC_ACTION (gaction);
 
-	g_value_init (&value, G_TYPE_STRING);
-	g_object_get_property (G_OBJECT (action), "label", &value);
-
-	label_text = g_value_get_string (&value);
+	g_return_if_fail (EPHY_IS_NODE (action->priv->topic_node));
 
+	/* note that we cannot use ellipsizing label with defined width,
+	 * since that makes the label exactly that wide, even if the
+	 * text takes less space. So we have to shorten the string.
+	 */
 	if (GTK_IS_TOOL_ITEM (proxy))
 	{
-		label = GTK_WIDGET (g_object_get_data (G_OBJECT (proxy), "label"));
-	}
-	else if (GTK_IS_MENU_ITEM (proxy))
-	{
-		label = GTK_BIN (proxy)->child;
-	}
-	else
-	{
-		g_warning ("Unknown widget");
-		return;
-	}
+		GtkWidget *label = NULL;
+		char *title;
 
-	g_return_if_fail (label != NULL);
+		label = g_object_get_data (G_OBJECT (proxy), "label");
+		g_return_if_fail (label != NULL);
 
-	if (label_text)
-	{
-		gtk_label_set_label (GTK_LABEL (label), label_text);
+		g_object_get (G_OBJECT (action), "label", &title, NULL);
+
+		gtk_label_set_label (GTK_LABEL (label), title);
+
+		g_free (title);
 	}
-
-	g_value_unset (&value);
 }
 
 static int
@@ -243,16 +233,16 @@ sort_bookmarks (gconstpointer a, gconstpointer b)
 	return retval;
 }
 
-#define MAX_LENGTH 32
-
 static gboolean
-can_open_in_tabs (EphyTopicAction *action)
+can_open_in_tabs (EphyNode *node)
 {
 	GPtrArray *children;
+	int priority;
 
-	children = ephy_node_get_children (action->priv->topic_node);
+	priority = ephy_node_get_property_int (node, EPHY_NODE_KEYWORD_PROP_PRIORITY);
+	children = ephy_node_get_children (node);
 
-	return (children->len > 1);
+	return (priority != EPHY_NODE_ALL_PRIORITY) && (children->len > 1);
 }
 
 static void
@@ -260,6 +250,7 @@ append_bookmarks_menu (EphyTopicAction *action, GtkWidget *menu, EphyNode *node,
 {
         EphyFaviconCache *cache;
 	GtkWidget *item;
+	GtkLabel *label;
 	GPtrArray *children;
 
         cache = EPHY_FAVICON_CACHE
@@ -290,24 +281,23 @@ append_bookmarks_menu (EphyTopicAction *action, GtkWidget *menu, EphyNode *node,
 
 		node_list = g_list_sort (node_list, (GCompareFunc)sort_bookmarks);
 
-		for (l = g_list_first (node_list); l != NULL; l = g_list_next (l))
+		for (l = node_list; l != NULL; l = l->next)
 		{
-			EphyNode *kid;
+			EphyNode *kid = (EphyNode*) l->data;
 			const char *icon_location;
 			const char *title;
-			char *title_short;
-
-			kid = (EphyNode*)l->data;
 
 			icon_location = ephy_node_get_property_string
 				(kid, EPHY_NODE_BMK_PROP_ICON);
 			title = ephy_node_get_property_string
 				(kid, EPHY_NODE_BMK_PROP_TITLE);
 			if (title == NULL) continue;
-			title_short = ephy_string_shorten (title, MAX_LENGTH);
-			LOG ("Create menu for bookmark %s", title_short)
 
-			item = gtk_image_menu_item_new_with_label (title_short);
+			item = gtk_image_menu_item_new_with_label (title);
+			label = (GtkLabel *) ((GtkBin *) item)->child;
+			gtk_label_set_max_width_chars (label, MENUITEM_WIDTH_CHARS);
+			gtk_label_set_ellipsize (label, PANGO_ELLIPSIZE_END);
+
 			if (icon_location)
 			{
 				GdkPixbuf *icon;
@@ -329,37 +319,48 @@ append_bookmarks_menu (EphyTopicAction *action, GtkWidget *menu, EphyNode *node,
 					  G_CALLBACK (menu_activate_cb), action);
 			gtk_widget_show (item);
 			gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-
-			g_free (title_short);
 		}
 
 		g_list_free (node_list);
 	}
 }
 
+#define TOPIC_NODE_DATA_KEY	"TopicNode"
+
 static void
-open_in_tabs_activate_cb (GtkWidget *menu, EphyTopicAction *action)
+open_in_tabs_activate_cb (GtkWidget *item, EphyTopicAction *action)
 {
-	GList *uri_list = NULL;
+	EphyNode *node;
 	GPtrArray *children;
+	EphyTab *tab = NULL;
+	GList *node_list = NULL, *l;
 	int i;
 
-	children = ephy_node_get_children (action->priv->topic_node);
-	for (i = 0; i < children->len; i++)
-	{
-		const char *address;
-		EphyNode *child;
+	node = g_object_get_data (G_OBJECT (item), TOPIC_NODE_DATA_KEY);
+	g_return_if_fail (node != NULL);
 
-		child = g_ptr_array_index (children, i);
-		address = ephy_node_get_property_string
-			(child, EPHY_NODE_BMK_PROP_LOCATION);
-		uri_list = g_list_append (uri_list, g_strdup (address));
+	children = ephy_node_get_children (node);
+	for (i = 0; i < children->len; ++i)
+	{
+		node_list = g_list_prepend (node_list,
+					    g_ptr_array_index (children, i));
 	}
 
-	g_signal_emit (action, ephy_topic_action_signals[OPEN_IN_TABS],
-		       0, uri_list);
-	g_list_foreach (uri_list, (GFunc)g_free, NULL);
-	g_list_free (uri_list);
+	node_list = g_list_sort (node_list, (GCompareFunc) sort_bookmarks);
+
+	for (l = node_list; l != NULL; l = l->next)
+	{
+		EphyNode *child = (EphyNode *) l->data;
+		const char *address;
+
+		address = ephy_node_get_property_string
+			(child, EPHY_NODE_BMK_PROP_LOCATION);
+
+		tab = ephy_link_open (EPHY_LINK (action), address, tab,
+				      tab ? EPHY_LINK_NEW_TAB : EPHY_LINK_NEW_WINDOW);
+	}
+
+	g_list_free (node_list);
 }
 
 static int
@@ -437,14 +438,23 @@ move_right_activate_cb (GtkWidget *menu, GtkWidget *proxy)
 }
 
 static GtkWidget *
-add_open_in_tabs_menu (EphyTopicAction *action, GtkWidget *menu)
+add_open_in_tabs_menu (EphyTopicAction *action,
+		       GtkWidget *menu,
+		       EphyNode *node)
 {
 	GtkWidget *item;
+	const char *label;
 
-	item = gtk_menu_item_new_with_mnemonic (_("_Open in Tabs"));
+	label = ngettext ("_Open in New Tab",
+			  "_Open in New Tabs",
+			  ephy_node_get_n_children (node));
+
+	item = gtk_menu_item_new_with_mnemonic (label);
 	gtk_widget_show (item);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
+	g_object_set_data (G_OBJECT (item), TOPIC_NODE_DATA_KEY, node);
+
 	g_signal_connect (item, "activate",
 			  G_CALLBACK (open_in_tabs_activate_cb), action);
 
@@ -460,7 +470,7 @@ build_bookmarks_menu (EphyTopicAction *action, EphyNode *node)
 
 	append_bookmarks_menu (action, menu, node, TRUE);
 
-	if (can_open_in_tabs (action))
+	if (can_open_in_tabs (node))
 	{
 		GtkWidget *item;
 
@@ -468,7 +478,7 @@ build_bookmarks_menu (EphyTopicAction *action, EphyNode *node)
 		gtk_widget_show (item);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
-		add_open_in_tabs_menu (action, menu);
+		add_open_in_tabs_menu (action, menu, node);
 	}
 
 	return menu;
@@ -546,15 +556,18 @@ build_topics_menu (EphyTopicAction *action)
 		EphyNode *kid;
 		const char *title;
 		GtkWidget *bmk_menu;
+		GtkLabel *label;
 
 		kid = (EphyNode*)l->data;
 		if (kid == all) continue;
 
 		title = ephy_node_get_property_string
 			(kid, EPHY_NODE_KEYWORD_PROP_NAME);
-		LOG ("Create menu for topic %s", title);
 
 		item = gtk_image_menu_item_new_with_label (title);
+		label = (GtkLabel *) ((GtkBin *) item)->child;
+		gtk_label_set_max_width_chars (label, MENUITEM_WIDTH_CHARS);
+		gtk_label_set_ellipsize (label, PANGO_ELLIPSIZE_END);
 
 		gtk_widget_show (item);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
@@ -574,7 +587,7 @@ build_topics_menu (EphyTopicAction *action)
 static GtkWidget *
 build_menu (EphyTopicAction *action)
 {
-	if (action->priv->topic_id == BOOKMARKS_NODE_ID)
+	if (ephy_node_get_id (action->priv->topic_node) == BOOKMARKS_NODE_ID)
 	{
 		return build_topics_menu (action);
 	}
@@ -674,13 +687,39 @@ button_toggled_cb (GtkWidget *button,
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)))
 	{
 		GtkWidget *menu;
+		GdkEvent *event;
+		guint32 event_time = 0;
+		guint event_button = 0;
 
 		menu = build_menu (action);
 		g_signal_connect (menu, "deactivate",
 				  G_CALLBACK (menu_deactivate_cb), button);
-		gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
-				ephy_gui_menu_position_under_widget,
-				button, 1, gtk_get_current_event_time ());
+
+		event = gtk_get_current_event ();
+		if (event != NULL)
+		{
+			if (event->type == GDK_BUTTON_PRESS)
+			{
+				event_button = ((GdkEventButton *) event)->button;
+				event_time = ((GdkEventButton *) event)->time;
+			}
+
+			gdk_event_free (event);
+		}
+
+		if (event_button == 0)
+		{
+			gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
+					ephy_gui_menu_position_under_widget,
+					button, 0 , gtk_get_current_event_time ());
+			gtk_menu_shell_select_first (GTK_MENU_SHELL (menu), FALSE);
+		}
+		else
+		{
+			gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
+					ephy_gui_menu_position_under_widget,
+					button, event_button, event_time);
+		}
 
 		g_object_set_data (G_OBJECT (button), "popup", menu);
 	}
@@ -691,21 +730,16 @@ create_menu_item (GtkAction *action)
 {
 	GtkWidget *menu, *menu_item;
 	GValue value = { 0, };
-	const char *tmp;
-	char *label_text;
+	const char *title;
 
 	g_value_init (&value, G_TYPE_STRING);
 	g_object_get_property (G_OBJECT (action), "label", &value);
 
-	tmp = g_value_get_string (&value);
-	label_text = ephy_string_double_underscores (tmp);
+	title = g_value_get_string (&value);
 
-	LOG ("create_menu_item action %p", action)
-
-	menu_item = gtk_menu_item_new_with_label (label_text);
+	menu_item = gtk_menu_item_new_with_label (title);
 
 	g_value_unset (&value);
-	g_free (label_text);
 
 	menu = build_menu (EPHY_TOPIC_ACTION (action));
 	gtk_widget_show (menu);
@@ -716,7 +750,9 @@ create_menu_item (GtkAction *action)
 }
 
 static void
-show_context_menu (EphyTopicAction *action, GtkWidget *proxy,
+show_context_menu (EphyTopicAction *action,
+		   GtkWidget *proxy,
+		   GdkEventButton *event,
 		   GtkMenuPositionFunc func)
 {
 	GtkWidget *menu, *item;
@@ -724,8 +760,8 @@ show_context_menu (EphyTopicAction *action, GtkWidget *proxy,
 
 	menu = gtk_menu_new ();
 
-	item = add_open_in_tabs_menu (action, menu);
-	gtk_widget_set_sensitive (item, can_open_in_tabs (action));
+	item = add_open_in_tabs_menu (action, menu, action->priv->topic_node);
+	gtk_widget_set_sensitive (item, can_open_in_tabs (action->priv->topic_node));
 
 	item = gtk_separator_menu_item_new ();
 	gtk_widget_show (item);
@@ -756,8 +792,17 @@ show_context_menu (EphyTopicAction *action, GtkWidget *proxy,
 	g_signal_connect (item, "activate",
 			  G_CALLBACK (move_right_activate_cb), proxy);
 
-	gtk_menu_popup (GTK_MENU (menu), NULL, NULL, func, proxy, 3,
-			gtk_get_current_event_time ());
+	if (event != NULL)
+	{
+		gtk_menu_popup (GTK_MENU (menu), NULL, NULL, func, proxy,
+				event->button, event->time);
+	}
+	else
+	{
+		gtk_menu_popup (GTK_MENU (menu), NULL, NULL, func, proxy, 0,
+				gtk_get_current_event_time ());
+		gtk_menu_shell_select_first (GTK_MENU_SHELL (menu), FALSE);
+	}
 }
 
 static gboolean
@@ -765,7 +810,7 @@ popup_menu_cb (GtkWidget *widget, EphyTopicAction *action)
 {
 	if (gtk_widget_get_ancestor (widget, EPHY_TYPE_BOOKMARKSBAR))
         {
-                show_context_menu (action, widget,
+                show_context_menu (action, widget, NULL,
 				   ephy_gui_menu_position_under_widget);
 		return TRUE;
         }
@@ -825,7 +870,7 @@ button_press_cb (GtkWidget *widget,
 	else if (event->button == 3 &&
 	         gtk_widget_get_ancestor (widget, EPHY_TYPE_BOOKMARKSBAR))	
 	{
-		show_context_menu (action, widget, NULL);
+		show_context_menu (action, widget, event, NULL);
 		return TRUE;
 	}
 
@@ -841,12 +886,12 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 
 	(* GTK_ACTION_CLASS (parent_class)->connect_proxy) (action, proxy);
 
-	ephy_topic_action_sync_label (action, NULL, proxy);
-	g_signal_connect_object (action, "notify::label",
-			         G_CALLBACK (ephy_topic_action_sync_label), proxy, 0);
-
 	if (GTK_IS_TOOL_ITEM (proxy))
 	{
+		ephy_topic_action_sync_label (action, NULL, proxy);
+		g_signal_connect_object (action, "notify::label",
+					 G_CALLBACK (ephy_topic_action_sync_label), proxy, 0);
+
 		button = GTK_WIDGET (g_object_get_data (G_OBJECT (proxy), "button"));
 		g_signal_connect (button, "toggled",
 				  G_CALLBACK (button_toggled_cb), action);
@@ -864,16 +909,46 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 }
 
 static void
-ephy_topic_action_set_topic_id (EphyTopicAction *action, guint id)
+topic_changed_cb (EphyNode *node,
+		  guint property_id,
+		  EphyTopicAction *action)
 {
-	EphyBookmarks *bookmarks;
-	EphyNode *node;
+	if (property_id == EPHY_NODE_KEYWORD_PROP_NAME)
+	{
+		GValue value = { 0, };
+		const char *title;
+		int priority;
 
-	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
-	node = ephy_bookmarks_get_from_id (bookmarks, id);
+		priority = ephy_node_get_property_int 
+			(node, EPHY_NODE_KEYWORD_PROP_PRIORITY);
 
+		if (priority == EPHY_NODE_ALL_PRIORITY)
+		{
+			title = _("Bookmarks");
+		}
+		else
+		{
+			title = ephy_node_get_property_string
+				(node, EPHY_NODE_KEYWORD_PROP_NAME);
+		}
+
+		g_value_init(&value, G_TYPE_STRING);
+		g_value_set_static_string (&value, title);
+		g_object_set_property (G_OBJECT (action), "label", &value);
+		g_value_unset (&value);
+	}
+}
+
+static void
+ephy_topic_action_set_topic (EphyTopicAction *action,
+			     EphyNode *node)
+{
 	action->priv->topic_node = node;
-	action->priv->topic_id = id;
+
+	topic_changed_cb (node, EPHY_NODE_KEYWORD_PROP_NAME, action);
+	ephy_node_signal_connect_object (node, EPHY_NODE_CHANGED,
+				         (EphyNodeCallback) topic_changed_cb,
+				         G_OBJECT (action));
 }
 
 static void
@@ -888,8 +963,8 @@ ephy_topic_action_set_property (GObject *object,
 
 	switch (prop_id)
 	{
-		case PROP_TOPIC_ID:
-			ephy_topic_action_set_topic_id (topic, g_value_get_int (value));
+		case PROP_TOPIC:
+			ephy_topic_action_set_topic (topic, g_value_get_pointer (value));
 			break;
 	}
 }
@@ -900,16 +975,8 @@ ephy_topic_action_get_property (GObject *object,
                                    GValue *value,
                                    GParamSpec *pspec)
 {
-	EphyTopicAction *bmk;
-
-	bmk = EPHY_TOPIC_ACTION (object);
-
-	switch (prop_id)
-	{
-		case PROP_TOPIC_ID:
-			g_value_set_boolean (value, bmk->priv->topic_id);
-			break;
-	}
+	/* no readable properties */
+	g_return_if_reached ();
 }
 
 static void
@@ -928,129 +995,30 @@ ephy_topic_action_class_init (EphyTopicActionClass *class)
 	object_class->set_property = ephy_topic_action_set_property;
 	object_class->get_property = ephy_topic_action_get_property;
 
-	ephy_topic_action_signals[OPEN] =
-                g_signal_new ("open",
-                              G_OBJECT_CLASS_TYPE (object_class),
-                              G_SIGNAL_RUN_FIRST,
-                              G_STRUCT_OFFSET (EphyTopicActionClass, open),
-                              NULL, NULL,
-                              g_cclosure_marshal_VOID__STRING,
-                              G_TYPE_NONE,
-                              1,
-			      G_TYPE_STRING);
-
-	ephy_topic_action_signals[OPEN_IN_TAB] =
-                g_signal_new ("open_in_tab",
-                              G_OBJECT_CLASS_TYPE (object_class),
-                              G_SIGNAL_RUN_FIRST,
-                              G_STRUCT_OFFSET (EphyTopicActionClass, open_in_tab),
-                              NULL, NULL,
-                              ephy_marshal_VOID__STRING_BOOLEAN,
-                              G_TYPE_NONE,
-                              2,
-			      G_TYPE_STRING,
-			      G_TYPE_BOOLEAN);
-
-	ephy_topic_action_signals[OPEN_IN_TABS] =
-                g_signal_new ("open_in_tabs",
-                              G_OBJECT_CLASS_TYPE (object_class),
-                              G_SIGNAL_RUN_FIRST,
-                              G_STRUCT_OFFSET (EphyTopicActionClass, open_in_tabs),
-                              NULL, NULL,
-                              g_cclosure_marshal_VOID__POINTER,
-                              G_TYPE_NONE,
-                              1,
-			      G_TYPE_POINTER);
-
-	g_object_class_install_property (object_class,
-                                         PROP_TOPIC_ID,
-                                         g_param_spec_int ("topic_id",
-                                                           "topic_id",
-                                                           "topic_id",
-							   0,
-							   G_MAXINT,
-                                                           0,
-                                                           G_PARAM_READWRITE));
+	g_object_class_install_property
+		(object_class,
+		 PROP_TOPIC,
+		 g_param_spec_pointer ("topic",
+				       "Topic",
+				       "Topic",
+				       G_PARAM_WRITABLE |
+				       G_PARAM_CONSTRUCT_ONLY));
 
 	g_type_class_add_private (object_class, sizeof(EphyTopicActionPrivate));
 }
 
-static void
-sync_topic_properties (GtkAction *action, EphyNode *bmk)
-{
-	const char *tmp;
-	char *title;
-	int priority;
-
-	priority = ephy_node_get_property_int 
-		(bmk, EPHY_NODE_KEYWORD_PROP_PRIORITY);
-
-	if (priority == EPHY_NODE_ALL_PRIORITY)
-	{
-		tmp = _("Bookmarks");
-	}
-	else
-	{
-		tmp = ephy_node_get_property_string
-        	        (bmk, EPHY_NODE_KEYWORD_PROP_NAME);
-	}
-
-	title = ephy_string_double_underscores (tmp);
-
-	g_object_set (action, "label", title, NULL);
-
-	g_free (title);
-}
-
-static void
-topic_child_changed_cb (EphyNode *node,
-			EphyNode *child,
-			guint property_id,
-			GtkAction *action)
-{
-	guint id;
-
-	id = EPHY_TOPIC_ACTION (action)->priv->topic_id;
-
-	if (id == ephy_node_get_id (child))
-	{
-		sync_topic_properties (action, child);
-	}
-}
-
 static void
 ephy_topic_action_init (EphyTopicAction *action)
 {
-	EphyBookmarks *bookmarks;
-	EphyNode *node;
-
 	action->priv = EPHY_TOPIC_ACTION_GET_PRIVATE (action);
-
-	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
-	node = ephy_bookmarks_get_keywords (bookmarks);
-	ephy_node_signal_connect_object (node, EPHY_NODE_CHILD_CHANGED,
-				         (EphyNodeCallback) topic_child_changed_cb,
-				         G_OBJECT (action));
 }
 
 GtkAction *
-ephy_topic_action_new (const char *name, guint id)
+ephy_topic_action_new (const char *name,
+		       EphyNode *node)
 {
-	EphyNode *bmk;
-	EphyBookmarks *bookmarks;
-	GtkAction *action;
-
-	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
-
-	bmk = ephy_bookmarks_get_from_id (bookmarks, id);
-	g_return_val_if_fail (bmk != NULL, NULL);
-
-	action = GTK_ACTION (g_object_new (EPHY_TYPE_TOPIC_ACTION,
-					   "topic_id", id,
-					   "name", name,
-					   NULL));
-
-	sync_topic_properties (action, bmk);
-
-	return action;
+	return g_object_new (EPHY_TYPE_TOPIC_ACTION,
+			     "name", name,
+			     "topic", node,
+			     NULL);
 }
