@@ -1,3 +1,4 @@
+
 /*
  *  Copyright (C) 2002-2004 Marco Pesenti Gritti <mpeseng@tin.it>
  *
@@ -15,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-topics-selector.c,v 1.28 2004/11/02 20:57:34 chpe Exp $
+ *  $Id: ephy-topics-selector.c,v 1.30 2005/01/08 19:41:47 chpe Exp $
  */
 
 #include "config.h"
@@ -24,13 +25,14 @@
 #include "ephy-debug.h"
 
 #include <glib/gi18n.h>
+#include <gtk/gtktreeselection.h>
 
 static void ephy_topics_selector_class_init (EphyTopicsSelectorClass *klass);
 static void ephy_topics_selector_init (EphyTopicsSelector *editor);
 
 #define EPHY_TOPICS_SELECTOR_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TOPICS_SELECTOR, EphyTopicsSelectorPrivate))
 
-struct EphyTopicsSelectorPrivate
+struct _EphyTopicsSelectorPrivate
 {
 	EphyBookmarks *bookmarks;
 	EphyNode *bookmark;
@@ -182,6 +184,7 @@ ephy_topics_selector_constructor (GType type,
 	GObject *object;
 	EphyTopicsSelector *selector;
 	EphyTopicsSelectorPrivate *priv;
+	GtkTreeSelection *selection;
 
 	object = parent_class->constructor (type, n_construct_properties,
                                             construct_params);
@@ -201,6 +204,9 @@ ephy_topics_selector_constructor (GType type,
 	ephy_node_view_set_sort (EPHY_NODE_VIEW (selector), G_TYPE_STRING,
 				 EPHY_NODE_KEYWORD_PROP_NAME, GTK_SORT_ASCENDING);
 
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (selector));
+	gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
+
 	return object;
 }
 
