@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-encoding-dialog.c,v 1.19 2004/11/02 20:57:20 chpe Exp $
+ *  $Id: ephy-encoding-dialog.c,v 1.20 2005/01/08 19:41:47 chpe Exp $
  */
 
 #include "config.h"
@@ -60,7 +60,7 @@ EphyDialogProperty properties [] =
 
 #define EPHY_ENCODING_DIALOG_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_ENCODING_DIALOG, EphyEncodingDialogPrivate))
 
-struct EphyEncodingDialogPrivate
+struct _EphyEncodingDialogPrivate
 {
 	EphyEncodings *encodings;
 	EphyWindow *window;
