@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti <mpeseng@tin.it>
+ *  Copyright (C) 2003, 2004 Marco Pesenti Gritti <mpeseng@tin.it>
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history-window.c,v 1.71.4.7 2004/12/03 01:26:06 chpe Exp $
+ *  $Id: ephy-history-window.c,v 1.89 2005/01/08 19:41:47 chpe Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <gtk/gtktable.h>
 #include <gtk/gtklabel.h>
@@ -41,6 +40,8 @@
 #include <gtk/gtkcombobox.h>
 #include <gtk/gtkuimanager.h>
 #include <gdk/gdkkeysyms.h>
+#include <gtk/gtkdialog.h>
+#include <gtk/gtkmessagedialog.h>
 #include <glib/gi18n.h>
 #include <libgnomeui/gnome-stock-icons.h>
 #include <string.h>
@@ -64,6 +65,9 @@
 #include "ephy-session.h"
 #include "ephy-favicon-cache.h"
 #include "eel-gconf-extensions.h"
+#include "ephy-node.h"
+#include "ephy-node-common.h"
+#include "ephy-node-view.h"
 
 static GtkTargetEntry page_drag_types [] =
 {
@@ -114,7 +118,7 @@ static void cmd_help_contents		  (GtkAction *action,
 #define CONF_HISTORY_DATE_FILTER "/apps/epiphany/dialogs/history_date_filter"
 #define CONF_HISTORY_VIEW_DETAILS "/apps/epiphany/dialogs/history_view_details"
 
-struct EphyHistoryWindowPrivate
+struct _EphyHistoryWindowPrivate
 {
 	EphyHistory *history;
 	GtkWidget *sites_view;
@@ -141,12 +145,14 @@ enum
 
 enum
 {
+	TIME_LAST_HALF_HOUR,
 	TIME_TODAY,
 	TIME_LAST_TWO_DAYS,
 	TIME_LAST_THREE_DAYS,
 	TIME_EVER
 };
 
+#define TIME_LAST_HALF_HOUR_STRING "last_half_hour"
 #define TIME_EVER_STRING "ever"
 #define TIME_TODAY_STRING "today"
 #define TIME_LAST_TWO_DAYS_STRING "last_two_days"
@@ -172,7 +178,7 @@ static GtkActionEntry ephy_history_ui_entries [] = {
 	{ "Delete", GTK_STOCK_DELETE, N_("_Delete"), NULL,
 	  N_("Delete the selected history link"),
 	  G_CALLBACK (cmd_delete) },
-	{ "BookmarkLink", STOCK_ADD_BOOKMARK, N_("Boo_kmark Link..."), "<control>D",
+	{ "BookmarkLink", STOCK_ADD_BOOKMARK, N_("Add _Bookmark..."), "<control>D",
 	  N_("Bookmark the selected history link"),
 	  G_CALLBACK (cmd_bookmark_link) },
 	{ "Close", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
@@ -192,7 +198,7 @@ static GtkActionEntry ephy_history_ui_entries [] = {
 	{ "SelectAll", NULL, N_("Select _All"), "<control>A",
 	  N_("Select all history links or text"),
 	  G_CALLBACK (cmd_select_all) },
-	{ "Clear", GTK_STOCK_CLEAR, N_("C_lear History"), NULL,
+	{ "Clear", GTK_STOCK_CLEAR, N_("Clear _History"), NULL,
 	  N_("Clear your browsing history"),
 	  G_CALLBACK (cmd_clear) },
 
@@ -226,99 +232,47 @@ static GtkRadioActionEntry ephy_history_radio_entries [] =
 };
 static guint ephy_history_n_radio_entries = G_N_ELEMENTS (ephy_history_radio_entries);
 
-
 static void
-confirmation_dialog_response_cb (GtkDialog *dialog, gint response,
+confirmation_dialog_response_cb (GtkWidget *dialog,
+				 int response,
 				 EphyHistoryWindow *editor)
 {
-	gtk_widget_destroy (GTK_WIDGET (dialog));
+	gtk_widget_destroy (dialog);
 
-	if (response != GTK_RESPONSE_OK)
-		return;
-
-	ephy_history_clear (editor->priv->history);
+	if (response == GTK_RESPONSE_ACCEPT)
+	{
+		ephy_history_clear (editor->priv->history);
+	}
 }
 
 static GtkWidget *
 confirmation_dialog_construct (EphyHistoryWindow *editor)
 {
-	GtkWidget *dialog;
-	GtkWidget *label;
-	GtkWidget *vbox;
-	GtkWidget *hbox;
-	GtkWidget *image;
-	GtkWidget *button;
-	GtkWidget *align;
-	char *str;
+	GtkWidget *dialog, *button, *image;
 
-	dialog = gtk_dialog_new_with_buttons (_("Clear History"),
-					     GTK_WINDOW (editor),
-					     GTK_DIALOG_DESTROY_WITH_PARENT |
-					     GTK_DIALOG_NO_SEPARATOR,
-					     NULL);
-	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 12);
-
-	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-
-	button = gtk_button_new ();
-	gtk_widget_show (button);
-	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
-	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-
-	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
-
-	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
-	gtk_widget_show (align);
-	gtk_container_add (GTK_CONTAINER (button), align);
-
-	hbox = gtk_hbox_new (FALSE, 2);
-	gtk_widget_show (hbox);
-	gtk_container_add (GTK_CONTAINER (align), hbox);
+	dialog = gtk_message_dialog_new
+		(GTK_WINDOW (editor),
+		 GTK_DIALOG_DESTROY_WITH_PARENT,
+		 GTK_MESSAGE_WARNING,
+		 GTK_BUTTONS_CANCEL,
+		 _("Clear browsing history?"));
 
+	gtk_message_dialog_format_secondary_text
+		(GTK_MESSAGE_DIALOG (dialog),
+		 _("Clearing the browsing history will cause all"
+		   " history links to be permanently deleted."));
+	
+	button = gtk_button_new_with_label (_("Cl_ear"));
 	image = gtk_image_new_from_stock (GTK_STOCK_CLEAR, GTK_ICON_SIZE_BUTTON);
+	gtk_button_set_image (GTK_BUTTON (button), image);
 	gtk_widget_show (image);
-	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
+	gtk_widget_show (button);
+	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_ACCEPT);
+	
+	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
 
-	label = gtk_label_new_with_mnemonic (_("C_lear"));
-	gtk_widget_show (label);
-	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-
-	hbox = gtk_hbox_new (FALSE, 12);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
-	gtk_widget_show (hbox);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), hbox,
-			    TRUE, TRUE, 0);
-
-	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING,
-					  GTK_ICON_SIZE_DIALOG);
-	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
-	gtk_widget_show (image);
-	gtk_box_pack_start (GTK_BOX (hbox), image, TRUE, TRUE, 0);
-
-	vbox = gtk_vbox_new (FALSE, 6);
-	gtk_widget_show (vbox);
-	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
-
-	label = gtk_label_new (NULL);
-	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	str = g_strconcat ("<b><big>", _("Clear browsing history?"),
-			   "</big></b>", NULL);
-	gtk_label_set_markup (GTK_LABEL (label), str);
-	g_free (str);
-	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
-	gtk_widget_show (label);
-
-	label = gtk_label_new (_("Clearing the browsing history will cause all"
-				 " history links to be permanently deleted."));
-	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
-	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
-	gtk_widget_show (label);
+	gtk_window_set_title (GTK_WINDOW (dialog), _("Clear History"));
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
 
 	g_signal_connect (dialog, "response",
 			  G_CALLBACK (confirmation_dialog_response_cb),
@@ -334,8 +288,8 @@ cmd_clear (GtkAction *action,
 	if (editor->priv->confirmation_dialog == NULL)
 	{
 		editor->priv->confirmation_dialog = confirmation_dialog_construct (editor);
-		g_object_add_weak_pointer (G_OBJECT(editor->priv->confirmation_dialog),
-					   (gpointer *)&editor->priv->confirmation_dialog);
+		g_object_add_weak_pointer (G_OBJECT (editor->priv->confirmation_dialog),
+					   (gpointer *) &editor->priv->confirmation_dialog);
 	}
 
 	gtk_widget_show (editor->priv->confirmation_dialog);
@@ -502,6 +456,23 @@ cmd_delete (GtkAction *action,
 	{
 		ephy_node_view_remove (EPHY_NODE_VIEW (editor->priv->pages_view));
 	}
+	else if (ephy_node_view_is_target (EPHY_NODE_VIEW (editor->priv->sites_view)))
+	{
+		EphyNodePriority priority;
+		GList *selected;
+		EphyNode *node;
+
+		selected = ephy_node_view_get_selection (EPHY_NODE_VIEW (editor->priv->sites_view));
+		node = selected->data;
+		priority = ephy_node_get_property_int (node, EPHY_NODE_KEYWORD_PROP_PRIORITY);
+
+		if (priority == -1) priority = EPHY_NODE_NORMAL_PRIORITY;
+
+		if (priority == EPHY_NODE_NORMAL_PRIORITY)
+		{
+			ephy_node_view_remove (EPHY_NODE_VIEW (editor->priv->sites_view));
+		}
+	}
 }
 
 static void
@@ -598,9 +569,9 @@ cmd_view_columns (GtkAction *action,
 GType
 ephy_history_window_get_type (void)
 {
-	static GType ephy_history_window_type = 0;
+	static GType type = 0;
 
-	if (ephy_history_window_type == 0)
+	if (G_UNLIKELY (type == 0))
 	{
 		static const GTypeInfo our_info =
 		{
@@ -615,12 +586,12 @@ ephy_history_window_get_type (void)
 			(GInstanceInitFunc) ephy_history_window_init
 		};
 
-		ephy_history_window_type = g_type_register_static (GTK_TYPE_WINDOW,
-							             "EphyHistoryWindow",
-							             &our_info, 0);
+		type = g_type_register_static (GTK_TYPE_WINDOW,
+					       "EphyHistoryWindow",
+					       &our_info, 0);
 	}
 
-	return ephy_history_window_type;
+	return type;
 }
 
 static void
@@ -701,9 +672,9 @@ ephy_history_window_update_menu (EphyHistoryWindow *editor)
 {
 	gboolean open_in_window, open_in_tab;
 	gboolean cut, copy, paste, select_all;
-	gboolean pages_focus, pages_selection;
-	gboolean pages_multiple_selection;
+	gboolean pages_focus, pages_selection, single_page_selected;
 	gboolean delete, bookmark_page;
+	int num_pages_selected;
 	GtkActionGroup *action_group;
 	GtkAction *action;
 	char *open_in_window_label, *open_in_tab_label, *copy_label;
@@ -711,9 +682,11 @@ ephy_history_window_update_menu (EphyHistoryWindow *editor)
 
 	pages_focus = ephy_node_view_is_target
 		(EPHY_NODE_VIEW (editor->priv->pages_view));
-	pages_selection = ephy_node_view_has_selection
-		(EPHY_NODE_VIEW (editor->priv->pages_view),
-		 &pages_multiple_selection);
+	num_pages_selected = gtk_tree_selection_count_selected_rows
+		 (gtk_tree_view_get_selection (GTK_TREE_VIEW (editor->priv->pages_view)));
+	pages_selection = num_pages_selected > 0;
+	single_page_selected = num_pages_selected == 1;
+
 	focus_widget = gtk_window_get_focus (GTK_WINDOW (editor));
 
 	if (GTK_IS_EDITABLE (focus_widget))
@@ -731,21 +704,17 @@ ephy_history_window_update_menu (EphyHistoryWindow *editor)
 	else
 	{
 		cut = FALSE;
-		copy = (pages_focus && !pages_multiple_selection && pages_selection);
+		copy = (pages_focus && single_page_selected);
 		paste = FALSE;
 		select_all = pages_focus;
 	}
 
-	if (pages_multiple_selection)
-	{
-		open_in_window_label = N_("_Open in New Windows");
-		open_in_tab_label = N_("Open in New _Tabs");
-	}
-	else
-	{
-		open_in_window_label = _("_Open in New Window");
-		open_in_tab_label = _("Open in New _Tab");
-	}
+	open_in_window_label = ngettext ("_Open in New Window",
+					 "_Open in New Windows",
+					 num_pages_selected);
+	open_in_tab_label = ngettext ("Open in New _Tab",
+				      "Open in New _Tabs",
+				      num_pages_selected);
 
 	if (pages_focus)
 	{
@@ -756,24 +725,23 @@ ephy_history_window_update_menu (EphyHistoryWindow *editor)
 		copy_label = _("_Copy");
 	}
 
-
 	open_in_window = (pages_focus && pages_selection);
 	open_in_tab = (pages_focus && pages_selection);
         delete = (pages_focus && pages_selection);
-	bookmark_page = (pages_focus && pages_selection && !pages_multiple_selection);
+	bookmark_page = (pages_focus && single_page_selected);
 
 	action_group = editor->priv->action_group;
 	action = gtk_action_group_get_action (action_group, "OpenInWindow");
-	g_object_set (action, "sensitive", open_in_window, NULL);
-	g_object_set (action, "label", open_in_window_label, NULL);
+	g_object_set (action, "sensitive", open_in_window,
+			      "label", open_in_window_label, NULL);
 	action = gtk_action_group_get_action (action_group, "OpenInTab");
-	g_object_set (action, "sensitive", open_in_tab, NULL);
-	g_object_set (action, "label", open_in_tab_label, NULL);
+	g_object_set (action, "sensitive", open_in_tab,
+			      "label", open_in_tab_label, NULL);
 	action = gtk_action_group_get_action (action_group, "Cut");
 	g_object_set (action, "sensitive", cut, NULL);
 	action = gtk_action_group_get_action (action_group, "Copy");
-	g_object_set (action, "sensitive", copy, NULL);
-	g_object_set (action, "label", copy_label, NULL);
+	g_object_set (action, "sensitive", copy,
+			      "label", copy_label, NULL);
 	action = gtk_action_group_get_action (action_group, "Paste");
 	g_object_set (action, "sensitive", paste, NULL);
 	action = gtk_action_group_get_action (action_group, "SelectAll");
@@ -905,6 +873,9 @@ add_by_date_filter (EphyHistoryWindow *editor,
 
 	switch (time_range)
 	{
+		case TIME_LAST_HALF_HOUR:
+			cmp_time = now - 30 * 60;
+			break;
 		case TIME_LAST_THREE_DAYS:
 			days++;
 			/* fall-through */
@@ -1072,6 +1043,7 @@ build_search_box (EphyHistoryWindow *editor)
 	combo = gtk_combo_box_new_text ();
 	gtk_widget_show (combo);
 
+	gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Last 30 Minutes"));
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combo), _("Today"));
 	str = g_strdup_printf (ngettext ("Last %d day", "Last %d days", 2), 2);
 	gtk_combo_box_append_text (GTK_COMBO_BOX (combo), str);
@@ -1085,6 +1057,10 @@ build_search_box (EphyHistoryWindow *editor)
 	g_free (str);
 
 	str = eel_gconf_get_string (CONF_HISTORY_DATE_FILTER);
+	if (str && strcmp (TIME_LAST_HALF_HOUR_STRING, str) == 0)
+	{
+		time_range = TIME_LAST_HALF_HOUR;
+	}
 	if (str && strcmp (TIME_TODAY_STRING, str) == 0)
 	{
 		time_range = TIME_TODAY;
@@ -1214,17 +1190,10 @@ ephy_history_window_construct (EphyHistoryWindow *editor)
 	EphyNode *node;
 	GtkUIManager *ui_merge;
 	GtkActionGroup *action_group;
-	GdkPixbuf *icon;
 	int col_id, details_value;
 
 	gtk_window_set_title (GTK_WINDOW (editor), _("History"));
-
-	icon = gtk_widget_render_icon (GTK_WIDGET (editor), 
-				       EPHY_STOCK_HISTORY,
-				       GTK_ICON_SIZE_MENU,
-				       NULL);
-	gtk_window_set_icon (GTK_WINDOW(editor), icon);
-	g_object_unref (icon);
+	gtk_window_set_icon_name (GTK_WINDOW (editor), EPHY_STOCK_HISTORY);
 
 	g_signal_connect (editor, "delete_event",
 			  G_CALLBACK (delete_event_cb), NULL);
@@ -1312,6 +1281,10 @@ ephy_history_window_construct (EphyHistoryWindow *editor)
 			  "node_selected",
 			  G_CALLBACK (site_node_selected_cb),
 			  editor);
+	g_signal_connect (G_OBJECT (sites_view),
+			  "key_press_event",
+			  G_CALLBACK (key_pressed_cb),
+			  editor);
 	g_signal_connect (G_OBJECT (selection),
 			  "changed",
 			  G_CALLBACK (view_selection_changed_cb),
@@ -1486,6 +1459,9 @@ save_date_filter (EphyHistoryWindow *editor)
 
 	switch (time_range)
 	{
+		case TIME_LAST_HALF_HOUR:
+			time_string = TIME_LAST_HALF_HOUR_STRING;
+			break;
 		case TIME_EVER:
 			time_string = TIME_EVER_STRING;
 			break;
