@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-session.c,v 1.33 2004/12/13 18:58:58 chpe Exp $
+ *  $Id: ephy-session.c,v 1.34 2005/01/08 16:40:45 chpe Exp $
  */
 
 #include "config.h"
@@ -51,7 +51,7 @@
 
 #define EPHY_SESSION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_SESSION, EphySessionPrivate))
 
-struct EphySessionPrivate
+struct _EphySessionPrivate
 {
 	GList *windows;
 	GList *tool_windows;
