@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-statusbar.c,v 1.14 2004/12/13 18:58:58 chpe Exp $
+ *  $Id: ephy-statusbar.c,v 1.15 2005/01/08 16:40:45 chpe Exp $
  */
 
 #include "config.h"
@@ -40,7 +40,7 @@ static GObjectClass *parent_class = NULL;
 
 #define EPHY_STATUSBAR_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_STATUSBAR, EphyStatusbarPrivate))
 
-struct EphyStatusbarPrivate
+struct _EphyStatusbarPrivate
 {
 	GtkWidget *icon_container;
 
