@@ -18,14 +18,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab.c,v 1.112.4.6 2005/01/22 18:32:01 chpe Exp $
+ *  $Id: ephy-tab.c,v 1.133 2005/01/09 01:52:18 adamh Exp $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-tab.h"
+#include "ephy-type-builtins.h"
+#include "ephy-embed-type-builtins.h"
 #include "eel-gconf-extensions.h"
 #include "ephy-prefs.h"
 #include "ephy-embed-factory.h"
@@ -77,7 +77,7 @@ struct _EphyTabPrivate
 	int load_percent;
 	gboolean visibility;
 	gboolean load_status;
-	TabAddressExpire address_expire;
+	EphyTabAddressExpire address_expire;
 	int cur_requests;
 	int total_requests;
 	int width;
@@ -85,10 +85,11 @@ struct _EphyTabPrivate
 	GtkToggleAction *action;
 	float zoom;
 	gboolean setting_zoom;
-	EmbedSecurityLevel security_level;
+	EphyEmbedSecurityLevel security_level;
 	GSList *hidden_popups;
 	GSList *shown_popups;
-	TabNavigationFlags nav_flags;
+	EphyTabNavigationFlags nav_flags;
+	EphyEmbedDocumentType document_type;
 };
 
 static void ephy_tab_class_init		(EphyTabClass *klass);
@@ -99,6 +100,7 @@ enum
 {
 	PROP_0,
 	PROP_ADDRESS,
+	PROP_DOCUMENT_TYPE,
 	PROP_ICON,
 	PROP_LOAD_PROGRESS,
 	PROP_LOAD_STATUS,
@@ -134,7 +136,7 @@ static void	ephy_tab_set_load_percent	(EphyTab *tab,
 static void	ephy_tab_update_navigation_flags(EphyTab *tab,
 						 EphyEmbed *embed);
 static void	ephy_tab_set_security_level	(EphyTab *tab,
-						 EmbedSecurityLevel level);
+						 EphyEmbedSecurityLevel level);
 static void	ephy_tab_set_title		(EphyTab *tab,
 						 EphyEmbed *embed,
 						 const char *new_title);
@@ -150,9 +152,9 @@ static void	ephy_tab_set_popups_allowed	(EphyTab *tab,
 GType
 ephy_tab_get_type (void)
 {
-        static GType ephy_tab_type = 0;
+        static GType type = 0;
 
-        if (ephy_tab_type == 0)
+        if (G_UNLIKELY (type == 0))
         {
                 static const GTypeInfo our_info =
                 {
@@ -167,12 +169,12 @@ ephy_tab_get_type (void)
                         (GInstanceInitFunc) ephy_tab_init
                 };
 
-                ephy_tab_type = g_type_register_static (GTK_TYPE_BIN,
-							"EphyTab",
-							&our_info, 0);
+                type = g_type_register_static (GTK_TYPE_BIN,
+					       "EphyTab",
+					       &our_info, 0);
         }
 
-        return ephy_tab_type;
+        return type;
 }
 
 static void
@@ -188,12 +190,13 @@ ephy_tab_set_property (GObject *object,
 	{
 		case PROP_ADDRESS:
 			ephy_tab_set_location (tab, g_value_get_string (value),
-					       TAB_ADDRESS_EXPIRE_NOW);
+					       EPHY_TAB_ADDRESS_EXPIRE_NOW);
 			break;
 		case PROP_POPUPS_ALLOWED:
 			ephy_tab_set_popups_allowed
 				(tab, g_value_get_boolean (value));
 			break;
+		case PROP_DOCUMENT_TYPE:
 		case PROP_ICON:
 		case PROP_LOAD_PROGRESS:
 		case PROP_LOAD_STATUS:
@@ -222,6 +225,9 @@ ephy_tab_get_property (GObject *object,
 		case PROP_ADDRESS:
 			g_value_set_string (value, tab->priv->address);
 			break;
+		case PROP_DOCUMENT_TYPE:
+			g_value_set_enum (value, tab->priv->document_type);
+			break;
 		case PROP_ICON:
 			g_value_set_string (value, tab->priv->icon_address);
 			break;
@@ -235,10 +241,10 @@ ephy_tab_get_property (GObject *object,
 			g_value_set_string (value, ephy_tab_get_status_message (tab));
 			break;
 		case PROP_NAVIGATION:
-			g_value_set_int (value, tab->priv->nav_flags);
+			g_value_set_flags (value, tab->priv->nav_flags);
 			break;
 		case PROP_SECURITY:
-			g_value_set_int (value, tab->priv->security_level);
+			g_value_set_enum (value, tab->priv->security_level);
 			break;
 		case PROP_HIDDEN_POPUP_COUNT:
 			g_value_set_int (value, popup_blocker_n_hidden (tab));
@@ -364,6 +370,15 @@ ephy_tab_class_init (EphyTabClass *class)
 							      "",
 							      G_PARAM_READWRITE));
 
+	g_object_class_install_property (object_class,
+					 PROP_DOCUMENT_TYPE,
+					 g_param_spec_enum ("document-type",
+							    "Document Type",
+							    "The tab's documen type",
+							    EPHY_TYPE_EMBED_DOCUMENT_TYPE,
+							    EPHY_EMBED_DOCUMENT_HTML,
+							    G_PARAM_READABLE));
+
 	g_object_class_install_property (object_class,
 					 PROP_ICON,
 					 g_param_spec_string ("icon",
@@ -400,25 +415,21 @@ ephy_tab_class_init (EphyTabClass *class)
 
 	g_object_class_install_property (object_class,
 					 PROP_NAVIGATION,
-					 g_param_spec_int ("navigation",
-							   "Navigation flags",
-							   "The tab's navigation flags",
-							    0,
-							    TAB_NAV_UP |
-							    TAB_NAV_BACK |
-							    TAB_NAV_FORWARD,
-							    0,
-							    G_PARAM_READABLE));
+					 g_param_spec_flags ("navigation",
+							     "Navigation flags",
+							     "The tab's navigation flags",
+							     EPHY_TYPE_TAB_NAVIGATION_FLAGS,
+							     0,
+							     G_PARAM_READABLE));
 
 	g_object_class_install_property (object_class,
 					 PROP_SECURITY,
-					 g_param_spec_int ("security-level",
-							   "Security Level",
-							   "The tab's security level",
-							    STATE_IS_UNKNOWN,
-							    STATE_IS_SECURE_HIGH,
-							    STATE_IS_UNKNOWN,
-							    G_PARAM_READABLE));
+					 g_param_spec_enum ("security-level",
+							    "Security Level",
+							    "The tab's security level",
+							    EPHY_TYPE_EMBED_SECURITY_LEVEL,
+							    EPHY_EMBED_STATE_IS_UNKNOWN,
+							     G_PARAM_READABLE));
 
 	g_object_class_install_property (object_class,
 					 PROP_HIDDEN_POPUP_COUNT,
@@ -448,7 +459,7 @@ ephy_tab_class_init (EphyTabClass *class)
 
 	g_object_class_install_property (object_class,
 					 PROP_VISIBLE,
-					 g_param_spec_boolean ("visibility",
+					 g_param_spec_boolean ("visible",
 							       "Visibility",
 							       "The tab's visibility",
 							       TRUE,
@@ -813,6 +824,22 @@ ephy_tab_set_load_status (EphyTab *tab, gboolean status)
 	g_object_notify (G_OBJECT (tab), "load-status");
 }
 
+/**
+ * ephy_tab_get_document_type:
+ * @tab: an #EphyTab
+ *
+ * Returns the type of the document loaded in @tab.
+ *
+ * Return value: the #EphyEmbedDocumentType
+ **/
+EphyEmbedDocumentType
+ephy_tab_get_document_type (EphyTab *tab)
+{
+	g_return_val_if_fail (EPHY_IS_TAB (tab), EPHY_EMBED_DOCUMENT_OTHER);
+
+	return tab->priv->document_type;
+}
+
 /**
  * ephy_tab_get_load_status:
  * @tab: an #EphyTab
@@ -1035,9 +1062,9 @@ ephy_tab_address_cb (EphyEmbed *embed, const char *address, EphyTab *tab)
 		uv_address = address;
 	}
 
-	if (tab->priv->address_expire == TAB_ADDRESS_EXPIRE_NOW)
+	if (tab->priv->address_expire == EPHY_TAB_ADDRESS_EXPIRE_NOW)
 	{
-		ephy_tab_set_location (tab, uv_address, TAB_ADDRESS_EXPIRE_NOW);
+		ephy_tab_set_location (tab, uv_address, EPHY_TAB_ADDRESS_EXPIRE_NOW);
 	}
 
 	ephy_tab_set_link_message (tab, NULL);
@@ -1080,6 +1107,19 @@ ephy_tab_content_change_cb (EphyEmbed *embed, const char *address, EphyTab *tab)
 	g_object_notify (G_OBJECT (tab), "popups-allowed");
 }
 
+static void
+ephy_tab_document_type_cb (EphyEmbed *embed,
+			   EphyEmbedDocumentType type,
+			   EphyTab *tab)
+{
+	if (tab->priv->document_type != type)
+	{
+		tab->priv->document_type = type;
+
+		g_object_notify (G_OBJECT (tab), "document-type");
+	}
+}
+
 static void
 ephy_tab_zoom_changed_cb (EphyEmbed *embed, float zoom, EphyTab *tab)
 {
@@ -1150,99 +1190,84 @@ build_load_percent (int requests_done, int requests_total)
 	return percent;
 }
 
-static char *
-get_host_name_from_uri (const char *uri)
+static void
+update_net_state_message (EphyTab *tab, const char *uri, EphyEmbedNetState flags)
 {
 	GnomeVFSURI *vfs_uri = NULL;
+	const char *msg = NULL;
 	const char *host = NULL;
-	char *result;
 
-	if (uri)
+	if (uri != NULL)
 	{
 		vfs_uri = gnome_vfs_uri_new (uri);
 	}
 
-	if (vfs_uri)
+	if (vfs_uri != NULL)
 	{
 		host = gnome_vfs_uri_get_host_name (vfs_uri);
 	}
 
-	if (!host)
-	{
-		host = _("site");
-	}
-
-	result = g_strdup (host);
-
-	if (vfs_uri) gnome_vfs_uri_unref (vfs_uri);
-
-	return result;
-}
-
-static void
-update_net_state_message (EphyTab *tab, const char *uri, EmbedState flags)
-{
-	const char *msg = NULL;
-	char *host;
-
-	host = get_host_name_from_uri (uri);
+	if (host == NULL || host[0] == '\0') goto out;
 
 	/* IS_REQUEST and IS_NETWORK can be both set */
-
-	if (flags & EMBED_STATE_IS_REQUEST)
-        {
-                if (flags & EMBED_STATE_REDIRECTING)
-                {
+	if (flags & EPHY_EMBED_STATE_IS_REQUEST)
+	{
+		if (flags & EPHY_EMBED_STATE_REDIRECTING)
+		{
 			msg = _("Redirecting to %s...");
-                }
-                else if (flags & EMBED_STATE_TRANSFERRING)
-                {
+		}
+		else if (flags & EPHY_EMBED_STATE_TRANSFERRING)
+		{
 			msg = _("Transferring data from %s...");
-                }
-                else if (flags & EMBED_STATE_NEGOTIATING)
-                {
+		}
+		else if (flags & EPHY_EMBED_STATE_NEGOTIATING)
+		{
 			msg = _("Waiting for authorization from %s...");
-                }
-        }
+		}
+	}
 
-	if (flags & EMBED_STATE_IS_NETWORK)
-        {
-                if (flags & EMBED_STATE_START)
-                {
-                        msg = _("Loading %s...");
-                }
-        }
+	if (flags & EPHY_EMBED_STATE_IS_NETWORK)
+	{
+		if (flags & EPHY_EMBED_STATE_START)
+		{
+			msg = _("Loading %s...");
+		}
+	}
 
-	if ((flags & EMBED_STATE_IS_NETWORK) &&
-	    (flags & EMBED_STATE_STOP))
-        {
+	if ((flags & EPHY_EMBED_STATE_IS_NETWORK) &&
+	    (flags & EPHY_EMBED_STATE_STOP))
+	{
 		g_free (tab->priv->status_message);
 		tab->priv->status_message = NULL;
 		g_object_notify (G_OBJECT (tab), "message");
 
 	}
-	else if (msg)
+	else if (msg != NULL)
 	{
 		g_free (tab->priv->status_message);
 		tab->priv->status_message = g_strdup_printf (msg, host);
 		g_object_notify (G_OBJECT (tab), "message");
 	}
 
-	g_free (host);
+out:
+	if (vfs_uri != NULL)
+	{
+		gnome_vfs_uri_unref (vfs_uri);
+	}
 }
 
 static void
-build_progress_from_requests (EphyTab *tab, EmbedState state)
+build_progress_from_requests (EphyTab *tab, EphyEmbedNetState state)
 {
 	int load_percent;
 
-	if (state & EMBED_STATE_IS_REQUEST)
+	if (state & EPHY_EMBED_STATE_IS_REQUEST)
         {
-                if (state & EMBED_STATE_START)
+                if (state & EPHY_EMBED_STATE_START)
                 {
 			tab->priv->total_requests ++;
 		}
-		else if (state & EMBED_STATE_STOP)
+		else if (state & EPHY_EMBED_STATE_STOP)
 		{
 			tab->priv->cur_requests ++;
 		}
@@ -1258,9 +1283,9 @@ static void
 ensure_page_info (EphyTab *tab, EphyEmbed *embed, const char *address)
 {
 	if ((tab->priv->address == NULL || *tab->priv->address == '\0') &&
-	    tab->priv->address_expire == TAB_ADDRESS_EXPIRE_NOW)
+	    tab->priv->address_expire == EPHY_TAB_ADDRESS_EXPIRE_NOW)
         {
-		ephy_tab_set_location (tab, address, TAB_ADDRESS_EXPIRE_NOW);
+		ephy_tab_set_location (tab, address, EPHY_TAB_ADDRESS_EXPIRE_NOW);
 	}
 
 	if (tab->priv->title == NULL)
@@ -1270,14 +1295,16 @@ ensure_page_info (EphyTab *tab, EphyEmbed *embed, const char *address)
 }
 
 static void
-ephy_tab_net_state_cb (EphyEmbed *embed, const char *uri,
-		       EmbedState state, EphyTab *tab)
+ephy_tab_net_state_cb (EphyEmbed *embed,
+		       const char *uri,
+		       EphyEmbedNetState state,
+		       EphyTab *tab)
 {
 	update_net_state_message (tab, uri, state);
 
-	if (state & EMBED_STATE_IS_NETWORK)
+	if (state & EPHY_EMBED_STATE_IS_NETWORK)
 	{
-		if (state & EMBED_STATE_START)
+		if (state & EPHY_EMBED_STATE_START)
 		{
 			tab->priv->total_requests = 0;
 			tab->priv->cur_requests = 0;
@@ -1287,21 +1314,22 @@ ephy_tab_net_state_cb (EphyEmbed *embed, const char *uri,
 			ephy_tab_set_load_status (tab, TRUE);
 			ephy_tab_update_navigation_flags (tab, embed);
 		}
-		else if (state & EMBED_STATE_STOP)
+		else if (state & EPHY_EMBED_STATE_STOP)
 		{
 			ephy_tab_set_load_percent (tab, 100);
 			ephy_tab_set_load_status (tab, FALSE);
 			ephy_tab_update_navigation_flags (tab, embed);
-			tab->priv->address_expire = TAB_ADDRESS_EXPIRE_NOW;
+			tab->priv->address_expire = EPHY_TAB_ADDRESS_EXPIRE_NOW;
 		}
 	}
 
 	build_progress_from_requests (tab, state);
 }
 
-static void
-ephy_tab_new_window_cb (EphyEmbed *embed, EphyEmbed **new_embed,
-			EphyEmbedChrome chromemask, EphyTab *tab)
+static EphyEmbed *
+ephy_tab_new_window_cb (EphyEmbed *embed,
+			EphyEmbedChrome chromemask,
+			EphyTab *tab)
 {
 	EphyTab *new_tab;
 	EphyWindow *window;
@@ -1323,9 +1351,9 @@ ephy_tab_new_window_cb (EphyEmbed *embed, EphyEmbed **new_embed,
 
         ephy_window_add_tab (window, new_tab, -1, FALSE);
 
-	*new_embed = ephy_tab_get_embed (new_tab);
-
 	popups_manager_add_window (tab, window);
+
+	return ephy_tab_get_embed (new_tab);
 }
 
 static void
@@ -1361,7 +1389,7 @@ ephy_tab_visibility_cb (EphyEmbed *embed, gboolean visibility,
 
 	tab->priv->visibility = visibility;
 
-	g_object_notify (G_OBJECT (tab), "visibility");
+	g_object_notify (G_OBJECT (tab), "visible");
 }
 
 static void
@@ -1456,7 +1484,7 @@ save_property_url (EphyEmbed *embed,
 	location = g_value_get_string (value);
 
 	persist = EPHY_EMBED_PERSIST
-		(ephy_embed_factory_new_object ("EphyEmbedPersist"));
+		(ephy_embed_factory_new_object (EPHY_TYPE_EMBED_PERSIST));
 
 	ephy_embed_persist_set_embed (persist, embed);
 	ephy_embed_persist_set_flags (persist, 0);
@@ -1494,7 +1522,7 @@ ephy_tab_dom_mouse_click_cb (EphyEmbed *embed,
 			     EphyTab *tab)
 {
 	EphyEmbedEventType type;
-	EmbedEventContext context;
+	EphyEmbedEventContext context;
 	guint modifier;
 	gboolean handled = TRUE;
 	gboolean with_control, with_shift, is_left_click, is_middle_click;
@@ -1520,12 +1548,12 @@ ephy_tab_dom_mouse_click_cb (EphyEmbed *embed,
 		eel_gconf_get_boolean (CONF_INTERFACE_MIDDLE_CLICK_OPEN_URL) &&
 		!eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_ARBITRARY_URL);
 
-	is_link = (context & EMBED_CONTEXT_LINK) != 0;
-	is_image = (context & EMBED_CONTEXT_IMAGE) != 0;
-	is_middle_clickable = !((context & EMBED_CONTEXT_LINK)
-				|| (context & EMBED_CONTEXT_INPUT)
-				|| (context & EMBED_CONTEXT_EMAIL_LINK));
-	is_input = (context & EMBED_CONTEXT_INPUT) != 0;
+	is_link = (context & EPHY_EMBED_CONTEXT_LINK) != 0;
+	is_image = (context & EPHY_EMBED_CONTEXT_IMAGE) != 0;
+	is_middle_clickable = !((context & EPHY_EMBED_CONTEXT_LINK)
+				|| (context & EPHY_EMBED_CONTEXT_INPUT)
+				|| (context & EPHY_EMBED_CONTEXT_EMAIL_LINK));
+	is_input = (context & EPHY_EMBED_CONTEXT_INPUT) != 0;
 
 	/* ctrl+click or middle click opens the link in new tab */
 	if (is_link && ((is_left_click && with_control) || is_middle_click))
@@ -1579,7 +1607,7 @@ ephy_tab_dom_mouse_click_cb (EphyEmbed *embed,
 }
 
 static void
-ephy_tab_security_change_cb (EphyEmbed *embed, EmbedSecurityLevel level,
+ephy_tab_security_change_cb (EphyEmbed *embed, EphyEmbedSecurityLevel level,
 			       EphyTab *tab)
 {
 	ephy_tab_set_security_level (tab, level);
@@ -1596,26 +1624,18 @@ ephy_tab_init (EphyTab *tab)
 
 	tab->priv = EPHY_TAB_GET_PRIVATE (tab);
 
-	tab->priv->status_message = NULL;
-	tab->priv->link_message = NULL;
 	tab->priv->total_requests = 0;
 	tab->priv->cur_requests = 0;
 	tab->priv->width = -1;
 	tab->priv->height = -1;
-	tab->priv->title = NULL;
-	tab->priv->address = NULL;
-	tab->priv->icon_address = NULL;
 	tab->priv->load_percent = 0;
 	tab->priv->load_status = FALSE;
-	tab->priv->link_message = NULL;
-	tab->priv->security_level = STATE_IS_UNKNOWN;
-	tab->priv->hidden_popups = NULL;
-	tab->priv->shown_popups = NULL;
+	tab->priv->security_level = EPHY_EMBED_STATE_IS_UNKNOWN;
+	tab->priv->document_type = EPHY_EMBED_DOCUMENT_HTML;
 	tab->priv->zoom = 1.0;
-	tab->priv->setting_zoom = FALSE;
-	tab->priv->address_expire = TAB_ADDRESS_EXPIRE_NOW;
+	tab->priv->address_expire = EPHY_TAB_ADDRESS_EXPIRE_NOW;
 
-	embed = ephy_embed_factory_new_object ("EphyEmbed");
+	embed = ephy_embed_factory_new_object (EPHY_TYPE_EMBED);
 	g_assert (embed != NULL);
 
 	gtk_container_add (GTK_CONTAINER (tab), GTK_WIDGET (embed));
@@ -1636,6 +1656,9 @@ ephy_tab_init (EphyTab *tab)
 	g_signal_connect_object (embed, "link_message",
 				 G_CALLBACK (ephy_tab_link_message_cb),
 				 tab, 0);
+	g_signal_connect_object (embed, "ge_document_type",
+				 G_CALLBACK (ephy_tab_document_type_cb),
+				 tab, 0);
 	g_signal_connect_object (embed, "ge_location",
 				 G_CALLBACK (ephy_tab_address_cb),
 				 tab, 0);
@@ -1722,21 +1745,21 @@ ephy_tab_get_load_percent (EphyTab *tab)
 static void
 ephy_tab_update_navigation_flags (EphyTab *tab, EphyEmbed *embed)
 {
-	TabNavigationFlags flags = 0;
+	EphyTabNavigationFlags flags = 0;
 
 	if (ephy_embed_can_go_up (embed))
 	{
-		flags |= TAB_NAV_UP;
+		flags |= EPHY_TAB_NAV_UP;
 	}
 
 	if (ephy_embed_can_go_back (embed))
 	{
-		flags |= TAB_NAV_BACK;
+		flags |= EPHY_TAB_NAV_BACK;
 	}
 
 	if (ephy_embed_can_go_forward (embed))
 	{
-		flags |= TAB_NAV_FORWARD;
+		flags |= EPHY_TAB_NAV_FORWARD;
 	}
 
 	if (flags != tab->priv->nav_flags)
@@ -1755,7 +1778,7 @@ ephy_tab_update_navigation_flags (EphyTab *tab, EphyEmbed *embed)
  *
  * Return value: @tab's navigation flags
  **/
-TabNavigationFlags
+EphyTabNavigationFlags
 ephy_tab_get_navigation_flags (EphyTab *tab)
 {
 	g_return_val_if_fail (EPHY_IS_TAB (tab), 0);
@@ -1803,7 +1826,6 @@ ephy_tab_get_status_message (EphyTab *tab)
 static void
 ephy_tab_set_title (EphyTab *tab, EphyEmbed *embed, const char *new_title)
 {
-	char *title_short, *title_tmp;
 	char *title = NULL;
 
 	g_return_if_fail (EPHY_IS_TAB (tab));
@@ -1852,20 +1874,10 @@ ephy_tab_set_title (EphyTab *tab, EphyEmbed *embed, const char *new_title)
 
 	tab->priv->title = title;
 
-	title_short = ephy_string_shorten (title, MAX_LABEL_LENGTH);
-	title_tmp = ephy_string_double_underscores (title_short);
-
-	/*
-	 * FIXME: instead of shortening the title here, use an egg action
-	 * which creates menu items with ellipsizing labels
-	 */
 	g_object_set (G_OBJECT (tab->priv->action),
-		      "label", title_tmp,
+		      "label", title,
 		      NULL);
 
-	g_free (title_short);
-	g_free (title_tmp);
-
 	g_object_notify (G_OBJECT (tab), "title");
 }
 
@@ -1918,17 +1930,17 @@ ephy_tab_get_location (EphyTab *tab)
 void
 ephy_tab_set_location (EphyTab *tab,
 		       const char *address,
-		       TabAddressExpire expire)
+		       EphyTabAddressExpire expire)
 {
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
 	if (tab->priv->address) g_free (tab->priv->address);
 	tab->priv->address = g_strdup (address);
 
-	if (expire == TAB_ADDRESS_EXPIRE_CURRENT &&
+	if (expire == EPHY_TAB_ADDRESS_EXPIRE_CURRENT &&
 	    !tab->priv->load_status)
 	{
-		tab->priv->address_expire = TAB_ADDRESS_EXPIRE_NOW;
+		tab->priv->address_expire = EPHY_TAB_ADDRESS_EXPIRE_NOW;
 	}
 	else
 	{
@@ -1939,7 +1951,7 @@ ephy_tab_set_location (EphyTab *tab,
 }
 
 static void
-ephy_tab_set_security_level (EphyTab *tab, EmbedSecurityLevel level)
+ephy_tab_set_security_level (EphyTab *tab, EphyEmbedSecurityLevel level)
 {
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
@@ -1956,10 +1968,10 @@ ephy_tab_set_security_level (EphyTab *tab, EmbedSecurityLevel level)
  *
  * Return value: @tab's loaded page's security level
  **/
-EmbedSecurityLevel
+EphyEmbedSecurityLevel
 ephy_tab_get_security_level (EphyTab *tab)
 {
-	g_return_val_if_fail (EPHY_IS_TAB (tab), STATE_IS_UNKNOWN);
+	g_return_val_if_fail (EPHY_IS_TAB (tab), EPHY_EMBED_STATE_IS_UNKNOWN);
 
 	return tab->priv->security_level;
 }
