@@ -17,12 +17,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.c,v 1.243 2004/12/19 13:26:37 chpe Exp $
+ *  $Id: ephy-window.c,v 1.254 2005/01/09 01:29:17 chpe Exp $
  */
 
 #include "config.h"
 
 #include "ephy-window.h"
+#include "ephy-type-builtins.h"
+#include "ephy-embed-type-builtins.h"
 #include "ephy-command-manager.h"
 #include "ephy-bookmarks-menu.h"
 #include "ephy-favorites-menu.h"
@@ -50,7 +52,9 @@
 #include "ephy-stock-icons.h"
 #include "ephy-extension.h"
 #include "ephy-favicon-cache.h"
+#include "ephy-link.h"
 #include "ephy-gui.h"
+#include "ephy-notebook.h"
 
 #include <string.h>
 #include <glib/gi18n.h>
@@ -99,6 +103,7 @@ static GtkActionEntry ephy_menu_entries [] = {
 	{ "Tabs", NULL, N_("_Tabs") },
 	{ "Help", NULL, N_("_Help") },
 	{ "PopupAction", NULL, "" },
+	{ "NotebookPopupAction", NULL, "" },
 
 	/* File menu */
 
@@ -129,8 +134,8 @@ static GtkActionEntry ephy_menu_entries [] = {
 	{ "FileSendTo", STOCK_SEND_MAIL, N_("S_end To..."), "<control>M",
 	  N_("Send a link of the current page"),
 	  G_CALLBACK (window_cmd_file_send_to) },
-	{ "FileCloseWindow", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
-	  N_("Close this window"),
+	{ "FileCloseTab", GTK_STOCK_CLOSE, N_("_Close"), "<control>W",
+	  N_("Close this tab"),
 	  G_CALLBACK (window_cmd_file_close_window) },
 
 	/* Edit menu */
@@ -216,9 +221,6 @@ static GtkActionEntry ephy_menu_entries [] = {
 	{ "GoUp", GTK_STOCK_GO_UP, N_("_Up"), "<alt>Up",
 	  N_("Go up one level"),
 	  G_CALLBACK (window_cmd_go_up) },
-	{ "GoHome", GTK_STOCK_HOME, N_("_Home"), "<alt>Home",
-	  N_("Go to the home page"),
-	  G_CALLBACK (window_cmd_go_home) },
 	{ "GoLocation", NULL, N_("_Location..."), "<control>L",
 	  N_("Go to a specified location"),
 	  G_CALLBACK (window_cmd_go_location) },
@@ -345,7 +347,6 @@ static guint ephy_popups_n_entries = G_N_ELEMENTS (ephy_popups_entries);
 
 #define CONF_LOCKDOWN_HIDE_MENUBAR "/apps/epiphany/lockdown/hide_menubar"
 #define CONF_DESKTOP_BG_PICTURE "/desktop/gnome/background/picture_filename"
-#define INSANE_NUMBER_OF_URLS 20
 
 #define BOOKMARKS_MENU_PATH "/menubar/BookmarksMenu"
 
@@ -1131,7 +1132,6 @@ setup_ui_manager (EphyWindow *window)
 	GtkActionGroup *action_group;
 	GtkAction *action;
 	GtkUIManager *manager;
-	GError *err = NULL;
 
 	window->priv->main_vbox = gtk_vbox_new (FALSE, 0);
 	gtk_widget_show (window->priv->main_vbox);
@@ -1176,8 +1176,6 @@ setup_ui_manager (EphyWindow *window)
 
 	action = gtk_action_group_get_action (action_group, "EditFind");
 	g_object_set (action, "is_important", TRUE, NULL);
-	action = gtk_action_group_get_action (action_group, "GoHome");
-	g_object_set (action, "is_important", TRUE, NULL);
 	action = gtk_action_group_get_action (action_group, "GoBookmarks");
 	g_object_set (action, "is_important", TRUE, NULL);
 
@@ -1195,14 +1193,6 @@ setup_ui_manager (EphyWindow *window)
 	g_signal_connect (manager, "add_widget", G_CALLBACK (add_widget), window);
 	gtk_window_add_accel_group (GTK_WINDOW (window),
 				    gtk_ui_manager_get_accel_group (manager));
-
-	gtk_ui_manager_add_ui_from_file
-		(manager, ephy_file ("epiphany-ui.xml"), &err);
-	if (err != NULL)
-	{
-		g_warning ("Could not merge epiphany-ui.xml: %s", err->message);
-		g_clear_error (&err);
-        }
 }
 
 static void
@@ -1228,15 +1218,15 @@ sync_tab_document_type (EphyTab *tab,
 {
 	GtkActionGroup *action_group;
 	GtkAction *action;
-	EmbedDocumentType type;
+	EphyEmbedDocumentType type;
 	gboolean can_find, enable;
 
 	/* update zoom actions */
 	sync_tab_zoom (tab, NULL, window);
 	
 	type = ephy_tab_get_document_type (tab);
-	can_find = (type != EMBED_DOCUMENT_IMAGE);
-	enable = (type == EMBED_DOCUMENT_HTML);
+	can_find = (type != EPHY_EMBED_DOCUMENT_IMAGE);
+	enable = (type == EPHY_EMBED_DOCUMENT_HTML);
 
 	action_group = window->priv->action_group;
 	action = gtk_action_group_get_action (action_group, "ViewEncoding");
@@ -1273,7 +1263,7 @@ sync_tab_icon (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 
 	gtk_window_set_icon (GTK_WINDOW (window), pixbuf);
 
-	toolbar_update_favicon (window->priv->toolbar);
+	toolbar_update_favicon (window->priv->toolbar, address);
 
 	if (pixbuf)
 	{
@@ -1311,7 +1301,7 @@ sync_tab_message (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 static void
 sync_tab_navigation (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 {
-	TabNavigationFlags flags;
+	EphyTabNavigationFlags flags;
 	GtkActionGroup *action_group;
 	GtkAction *action;
 	gboolean up = FALSE, back = FALSE, forward = FALSE;
@@ -1321,15 +1311,15 @@ sync_tab_navigation (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 
 	flags = ephy_tab_get_navigation_flags (tab);
 
-	if (flags & TAB_NAV_UP)
+	if (flags & EPHY_TAB_NAV_UP)
 	{
 		up = TRUE;
 	}
-	if (flags & TAB_NAV_BACK)
+	if (flags & EPHY_TAB_NAV_BACK)
 	{
 		back = TRUE;
 	}
-	if (flags & TAB_NAV_FORWARD)
+	if (flags & EPHY_TAB_NAV_FORWARD)
 	{
 		forward = TRUE;
 	}
@@ -1358,7 +1348,7 @@ static void
 sync_tab_security (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 {
 	EphyEmbed *embed;
-	EmbedSecurityLevel level;
+	EphyEmbedSecurityLevel level;
 	char *description = NULL;
 	char *state = NULL;
 	char *tooltip;
@@ -1372,25 +1362,29 @@ sync_tab_security (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 
 	switch (level)
 	{
-		case STATE_IS_UNKNOWN:
+		case EPHY_EMBED_STATE_IS_UNKNOWN:
 			state = _("Unknown");
 			break;
-		case STATE_IS_INSECURE:
+		case EPHY_EMBED_STATE_IS_INSECURE:
 			state = _("Insecure");
+			g_free (description);
+			description = NULL;
 			break;
-		case STATE_IS_BROKEN:
+		case EPHY_EMBED_STATE_IS_BROKEN:
 			state = _("Broken");
 			stock_id = STOCK_LOCK_BROKEN;
+			g_free (description);
+			description = NULL;
 			break;
-		case STATE_IS_SECURE_MED:
-			state = _("Medium");
-			stock_id = STOCK_LOCK_SECURE;
-			break;
-		case STATE_IS_SECURE_LOW:
+		case EPHY_EMBED_STATE_IS_SECURE_LOW:
+		case EPHY_EMBED_STATE_IS_SECURE_MED:
 			state = _("Low");
-			stock_id = STOCK_LOCK_SECURE;
+			/* We deliberately don't show the 'secure' icon
+			 * for low & medium secure sites; see bug #151709.
+			 */
+			stock_id = STOCK_LOCK_INSECURE;
 			break;
-		case STATE_IS_SECURE_HIGH:
+		case EPHY_EMBED_STATE_IS_SECURE_HIGH:
 			state = _("High");
 			stock_id = STOCK_LOCK_SECURE;
 			break;
@@ -1399,16 +1393,14 @@ sync_tab_security (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 			break;
 	}
 
+	tooltip = g_strdup_printf (_("Security level: %s"), state);
 	if (description != NULL)
 	{
-		tooltip = g_strdup_printf (_("Security level: %s\n%s"),
-					   state, description);
-		g_free (description);
-	}
-	else
-	{
-		tooltip = g_strdup_printf (_("Security level: %s"), state);
+		char *tmp = tooltip;
 
+		tooltip = g_strconcat (tmp, "\n", description, NULL);
+		g_free (description);
+		g_free (tmp);
 	}
 
 	ephy_statusbar_set_security_state (EPHY_STATUSBAR (window->priv->statusbar),
@@ -1554,7 +1546,7 @@ sync_tab_zoom (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 {
 	GtkActionGroup *action_group;
 	GtkAction *action;
-	EmbedDocumentType type;
+	EphyEmbedDocumentType type;
 	gboolean can_zoom_in = TRUE, can_zoom_out = TRUE, can_zoom_normal = FALSE, can_zoom;
 	float zoom;
 
@@ -1562,7 +1554,7 @@ sync_tab_zoom (EphyTab *tab, GParamSpec *pspec, EphyWindow *window)
 
 	zoom = ephy_tab_get_zoom (tab);
 	type = ephy_tab_get_document_type (tab);
-	can_zoom = (type != EMBED_DOCUMENT_IMAGE);
+	can_zoom = (type != EPHY_EMBED_DOCUMENT_IMAGE);
 
 	if (zoom >= ZOOM_MAXIMAL)
 	{
@@ -1651,7 +1643,7 @@ get_name_from_address_value (const GValue *value)
 static void
 update_popups_tooltips (EphyWindow *window, EphyEmbedEvent *event)
 {
-	EmbedEventContext context;
+	EphyEmbedEventContext context;
 	GtkActionGroup *group = window->priv->popups_action_group;
 	const GValue *value;
 	GtkAction *action;
@@ -1671,7 +1663,7 @@ update_popups_tooltips (EphyWindow *window, EphyEmbedEvent *event)
 
 	context = ephy_embed_event_get_context (event);
 
-	if (context & EMBED_CONTEXT_IMAGE)
+	if (context & EPHY_EMBED_CONTEXT_IMAGE)
 	{
 		ephy_embed_event_get_property (event, "image", &value);
 		name = get_name_from_address_value (value);
@@ -1700,7 +1692,7 @@ update_popups_tooltips (EphyWindow *window, EphyEmbedEvent *event)
 		g_free (name);
 	}
 
-	if (context & EMBED_CONTEXT_EMAIL_LINK)
+	if (context & EPHY_EMBED_CONTEXT_EMAIL_LINK)
 	{
 		ephy_embed_event_get_property (event, "link", &value);
 
@@ -1717,7 +1709,7 @@ update_popups_tooltips (EphyWindow *window, EphyEmbedEvent *event)
 		g_free (tooltip);
 	}
 
-	if (context & EMBED_CONTEXT_LINK)
+	if (context & EPHY_EMBED_CONTEXT_LINK)
 	{
 		ephy_embed_event_get_property (event, "link", &value);
 
@@ -1747,7 +1739,7 @@ show_embed_popup (EphyWindow *window, EphyTab *tab, EphyEmbedEvent *event)
 {
 	GtkActionGroup *action_group;
 	GtkAction *action;
-	EmbedEventContext context;
+	EphyEmbedEventContext context;
 	const char *popup;
 	const GValue *value;
 	gboolean framed, has_background, can_open_in_new;
@@ -1770,31 +1762,31 @@ show_embed_popup (EphyWindow *window, EphyTab *tab, EphyEmbedEvent *event)
 
 	LOG ("show_embed_popup context %x", context)
 
-	if ((context & EMBED_CONTEXT_EMAIL_LINK) &&
-	    (context & EMBED_CONTEXT_IMAGE))
+	if ((context & EPHY_EMBED_CONTEXT_EMAIL_LINK) &&
+	    (context & EPHY_EMBED_CONTEXT_IMAGE))
 	{
 		popup = "/EphyImageEmailLinkPopup";
 	}
-	else if (context & EMBED_CONTEXT_EMAIL_LINK)
+	else if (context & EPHY_EMBED_CONTEXT_EMAIL_LINK)
 	{
 		popup = "/EphyEmailLinkPopup";
 		update_edit_actions_sensitivity (window, TRUE);
 	}
-	else if ((context & EMBED_CONTEXT_LINK) &&
-		 (context & EMBED_CONTEXT_IMAGE))
+	else if ((context & EPHY_EMBED_CONTEXT_LINK) &&
+		 (context & EPHY_EMBED_CONTEXT_IMAGE))
 	{
 		popup = "/EphyImageLinkPopup";
 	}
-	else if (context & EMBED_CONTEXT_LINK)
+	else if (context & EPHY_EMBED_CONTEXT_LINK)
 	{
 		popup = "/EphyLinkPopup";
 		update_edit_actions_sensitivity (window, TRUE);
 	}
-	else if (context & EMBED_CONTEXT_IMAGE)
+	else if (context & EPHY_EMBED_CONTEXT_IMAGE)
 	{
 		popup = "/EphyImagePopup";
 	}
-	else if (context & EMBED_CONTEXT_INPUT)
+	else if (context & EPHY_EMBED_CONTEXT_INPUT)
 	{
 		popup = "/EphyInputPopup";
 		update_edit_actions_sensitivity (window, FALSE);
@@ -2060,6 +2052,69 @@ modal_alert_cb (EphyEmbed *embed,
 	return FALSE;
 }
 
+static gboolean
+show_notebook_popup_menu (GtkNotebook *notebook,
+			  EphyWindow *window,
+			  GdkEventButton *event)
+{
+	GtkWidget *menu, *tab, *tab_label;
+	GtkAction *action;
+
+	menu = gtk_ui_manager_get_widget (window->priv->manager, "/EphyNotebookPopup");
+	g_return_val_if_fail (menu != NULL, FALSE);
+
+	/* allow extensions to sync when showing the popup */
+	action = gtk_action_group_get_action (window->priv->action_group,
+					      "NotebookPopupAction");
+	g_return_val_if_fail (action != NULL, FALSE);
+	gtk_action_activate (action);
+
+	if (event != NULL)
+	{
+		gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
+				NULL, NULL,
+				event->button, event->time);
+	}
+	else
+	{
+		tab = GTK_WIDGET (ephy_window_get_active_tab (window));
+		tab_label = gtk_notebook_get_tab_label (notebook, tab);
+
+		gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
+				ephy_gui_menu_position_under_widget, tab_label,
+				0, gtk_get_current_event_time ());
+		gtk_menu_shell_select_first (GTK_MENU_SHELL (menu), FALSE);
+	}
+
+	return TRUE;
+}
+
+static gboolean
+notebook_button_press_cb (GtkNotebook *notebook,
+			  GdkEventButton *event,
+			  EphyWindow *window)
+{
+	if (GDK_BUTTON_PRESS == event->type && 3 == event->button)
+	{
+		return show_notebook_popup_menu (notebook, window, event);
+	}
+
+	return FALSE;
+}
+
+static gboolean
+notebook_popup_menu_cb (GtkNotebook *notebook,
+			EphyWindow *window)
+{
+	/* Only respond if the notebook is the actual focus */
+	if (EPHY_IS_NOTEBOOK (gtk_window_get_focus (GTK_WINDOW (window))))
+	{
+		return show_notebook_popup_menu (notebook, window, NULL);
+	}
+
+	return FALSE;
+}
+
 static void
 tab_added_cb (EphyNotebook *notebook,
 	      EphyTab *tab,
@@ -2179,6 +2234,11 @@ setup_notebook (EphyWindow *window)
 				ephy_window_notebook_switch_page_cb),
 				window);
 
+	g_signal_connect (notebook, "popup-menu",
+			  G_CALLBACK (notebook_popup_menu_cb), window);
+	g_signal_connect (notebook, "button-press-event",
+			  G_CALLBACK(notebook_button_press_cb), window);
+
 	g_signal_connect (G_OBJECT (notebook), "tab_added",
 			  G_CALLBACK (tab_added_cb), window);
 	g_signal_connect (G_OBJECT (notebook), "tab_removed",
@@ -2332,7 +2392,7 @@ ephy_window_class_init (EphyWindowClass *klass)
 					 g_param_spec_flags ("chrome",
 							     "chrome",
 							     "Window chrome",
-							     EPHY_TYPE_EMBED_CHROME_MASK,
+							     EPHY_TYPE_EMBED_CHROME,
 							     EPHY_EMBED_CHROME_ALL,
 							     G_PARAM_CONSTRUCT_ONLY |
 							     G_PARAM_READWRITE));
@@ -2420,13 +2480,57 @@ action_request_forward_cb (GObject *toolbar,
 	g_signal_emit_by_name (bookmarksbar, "action_request", name);
 }
 
-static void
-open_bookmark_cb (EphyBookmarksMenu *menu,
-		  const char *location,
-		  gboolean open_in_new,
-		  EphyWindow *window)
+static EphyTab *
+open_link_cb (EphyLink *link,
+	      const char *address,
+	      EphyTab *tab,
+	      EphyLinkFlags flags,
+	      EphyWindow *window)
 {
-	ephy_window_load_url (window, location);
+	EphyTab *new_tab;
+
+	g_return_val_if_fail (address != NULL, NULL);
+
+	if (tab == NULL)
+	{
+		tab = ephy_window_get_active_tab (window);
+	}
+
+	if (flags != 0)
+	{
+		EphyNewTabFlags ntflags = EPHY_NEW_TAB_OPEN_PAGE;
+
+		if (flags & EPHY_LINK_JUMP_TO)
+		{
+			ntflags |= EPHY_NEW_TAB_JUMP;
+		}
+		if (flags & EPHY_LINK_NEW_WINDOW)
+		{
+			ntflags |= EPHY_NEW_TAB_IN_NEW_WINDOW;
+		}
+		else
+		{
+			ntflags |= EPHY_NEW_TAB_IN_EXISTING_WINDOW;
+		}
+
+		new_tab = ephy_shell_new_tab
+				(ephy_shell,
+				 EPHY_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (tab))),
+				 tab, address, ntflags);
+	}
+	else
+	{
+		EphyEmbed *embed;
+		
+		embed = ephy_tab_get_embed (tab);
+
+		ephy_embed_load_url (embed, address);
+		ephy_embed_activate (embed);
+
+		new_tab = tab;
+	}
+
+	return new_tab;
 }
 
 static void
@@ -2435,6 +2539,7 @@ ephy_window_init (EphyWindow *window)
 	EphyExtension *manager;
 	EphyEmbedSingle *single;
 	EggToolbarsModel *model;
+	GError *error = NULL;
 
 	LOG ("EphyWindow initialising %p", window)
 
@@ -2450,6 +2555,8 @@ ephy_window_init (EphyWindow *window)
 	setup_ui_manager (window);
 
 	window->priv->notebook = setup_notebook (window);
+	g_signal_connect (window->priv->notebook, "open-link",
+			  G_CALLBACK (open_link_cb), window);
 	gtk_box_pack_start (GTK_BOX (window->priv->main_vbox),
 			    GTK_WIDGET (window->priv->notebook),
 			    TRUE, TRUE, 0);
@@ -2464,16 +2571,6 @@ ephy_window_init (EphyWindow *window)
 	window->priv->help_message_cid = gtk_statusbar_get_context_id
 		(GTK_STATUSBAR (window->priv->statusbar), "help_message");
 
-	/* Initialize the menus */
-	window->priv->tabs_menu = ephy_tabs_menu_new (window);
-	window->priv->fav_menu = ephy_favorites_menu_new (window);
-	window->priv->enc_menu = ephy_encoding_menu_new (window);
-
-	window->priv->bmk_menu = ephy_bookmarks_menu_new (window->priv->manager,
-							  BOOKMARKS_MENU_PATH);
-	g_signal_connect (window->priv->bmk_menu, "open",
-			  G_CALLBACK (open_bookmark_cb), window);
-
 	/* get the toolbars model *before* getting the bookmarksbar model
 	 * (via ephy_bookmarsbar_new()), so that the toolbars model is
 	 * instantiated *before* the bookmarksbarmodel, to make forwarding
@@ -2483,11 +2580,35 @@ ephy_window_init (EphyWindow *window)
 
 	/* create the toolbars */
 	window->priv->toolbar = toolbar_new (window);
+	g_signal_connect (window->priv->toolbar, "open-link",
+			  G_CALLBACK (open_link_cb), window);
 	window->priv->bookmarksbar = ephy_bookmarksbar_new (window);
+	g_signal_connect (window->priv->bookmarksbar, "open-link",
+			  G_CALLBACK (open_link_cb), window);
 
 	g_signal_connect_swapped (window->priv->toolbar, "activation-finished",
 				  G_CALLBACK (sync_chromes_visibility), window);
 
+	/* now load the UI definition */
+	gtk_ui_manager_add_ui_from_file
+		(window->priv->manager, ephy_file ("epiphany-ui.xml"), &error);
+	if (error != NULL)
+	{
+		g_warning ("Could not merge epiphany-ui.xml: %s", error->message);
+		g_error_free (error);
+        }
+
+	/* Initialize the menus */
+	window->priv->tabs_menu = ephy_tabs_menu_new (window);
+	window->priv->enc_menu = ephy_encoding_menu_new (window);
+	window->priv->fav_menu = ephy_favorites_menu_new (window);
+	g_signal_connect (window->priv->fav_menu, "open-link",
+			  G_CALLBACK (open_link_cb), window);
+	window->priv->bmk_menu = ephy_bookmarks_menu_new (window->priv->manager,
+							  BOOKMARKS_MENU_PATH);
+	g_signal_connect (window->priv->bmk_menu, "open-link",
+			  G_CALLBACK (open_link_cb), window);
+
 	/* forward the toolbar's action_request signal to the bookmarks toolbar,
 	 * so the user can also have bookmarks on the normal toolbar
 	 */
@@ -3095,46 +3216,6 @@ ephy_window_set_zoom (EphyWindow *window,
 	}
 }
 
-void
-ephy_window_load_in_tabs (EphyWindow *window,
-			  EphyTab *tab,
-			  char **uris)
-{
-	EphyEmbed *embed = NULL;
-	guint num;
-
-	g_return_if_fail (uris != NULL);
-
-	if (tab != NULL)
-	{
-		embed = ephy_tab_get_embed (tab);
-		g_return_if_fail (EPHY_IS_EMBED (embed));
-	}
-
-	for (num = 0; uris[num] != NULL && num < INSANE_NUMBER_OF_URLS; num++)
-	{
-		const char *url = uris[num];
-	
-		if (num == 0 && embed != NULL)
-		{
-			/**
-			 * The first url is special: if the drag was to an
-			 * existing tab, load it there
-			 */
-			ephy_embed_load_url (embed, url);
-		}
-		else
-		{
-			tab = ephy_shell_new_tab (ephy_shell, window,
-						  tab, url,
-						  EPHY_NEW_TAB_OPEN_PAGE |
-						  EPHY_NEW_TAB_IN_EXISTING_WINDOW |
-						  (tab ? EPHY_NEW_TAB_APPEND_AFTER :
-							 EPHY_NEW_TAB_APPEND_LAST));
-		}
-	}
-}
-
 static void
 sync_prefs_with_chrome (EphyWindow *window)
 {
