@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: popup-commands.c,v 1.45 2004/11/02 20:57:21 chpe Exp $
+ *  $Id: popup-commands.c,v 1.50 2005/01/06 00:28:41 chpe Exp $
  */
 
 #include "config.h"
@@ -32,6 +32,10 @@
 #include <string.h>
 #include <glib/gi18n.h>
 #include <gtk/gtkclipboard.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
+#include <libgnomevfs/gnome-vfs-file-info.h>
+#include <libgnomevfs/gnome-vfs-ops.h>
+#include <libgnomevfs/gnome-vfs-mime-handlers.h>
 
 static EphyEmbedEvent *
 get_event_info (EphyWindow *window)
@@ -155,7 +159,7 @@ popup_cmd_copy_link_address (GtkAction *action,
 			     EphyWindow *window)
 {
 	EphyEmbedEvent *event;
-	EmbedEventContext context;
+	EphyEmbedEventContext context;
 	const char *address;
 	const GValue *value;
 
@@ -164,13 +168,13 @@ popup_cmd_copy_link_address (GtkAction *action,
 
 	context = ephy_embed_event_get_context (event);
 
-	if (context & EMBED_CONTEXT_EMAIL_LINK)
+	if (context & EPHY_EMBED_CONTEXT_EMAIL_LINK)
 	{
 		ephy_embed_event_get_property (event, "email", &value);
 		address = g_value_get_string (value);
 		popup_cmd_copy_to_clipboard (window, address);
 	}
-	else if (context & EMBED_CONTEXT_LINK)
+	else if (context & EPHY_EMBED_CONTEXT_LINK)
 	{
 		ephy_embed_event_get_property (event, "link", &value);
 		address = g_value_get_string (value);
@@ -205,7 +209,7 @@ save_property_url (GtkAction *action,
 	ephy_embed_persist_set_fc_title (persist, title);
 	ephy_embed_persist_set_fc_parent (persist, GTK_WINDOW (window));
 	ephy_embed_persist_set_flags
-		(persist, ask_dest ? EMBED_PERSIST_ASK_DESTINATION : 0);
+		(persist, ask_dest ? EPHY_EMBED_PERSIST_ASK_DESTINATION : 0);
 	ephy_embed_persist_set_persist_key
 		(persist, CONF_STATE_SAVE_DIR);
 	ephy_embed_persist_set_source (persist, location);
@@ -259,13 +263,14 @@ popup_cmd_save_image_as (GtkAction *action,
 
 #define CONF_DESKTOP_BG_PICTURE "/desktop/gnome/background/picture_filename"
 #define CONF_DESKTOP_BG_TYPE "/desktop/gnome/background/picture_options"
+#define GNOME_BACKGROUND_PREFERENCES "gnome-background-properties"
 
 static void
 background_download_completed (EphyEmbedPersist *persist,
 			       gpointer data)
 {
 	const char *bg;
-	char *type;
+	char *type, *path;
 
 	bg = ephy_embed_persist_get_dest (persist);
 	eel_gconf_set_string (CONF_DESKTOP_BG_PICTURE, bg);
@@ -278,6 +283,14 @@ background_download_completed (EphyEmbedPersist *persist,
 	g_free (type);
 
 	g_object_unref (persist);
+
+	/* open the "Background Properties" capplet */
+	path = g_find_program_in_path (GNOME_BACKGROUND_PREFERENCES);
+	if (path != NULL)
+	{
+		g_spawn_command_line_async (path, NULL);
+		g_free (path);
+	}
 }
 
 void
@@ -307,7 +320,7 @@ popup_cmd_set_image_as_background (GtkAction *action,
 
 	ephy_embed_persist_set_embed (persist, embed);
 	ephy_embed_persist_set_dest (persist, dest);
-	ephy_embed_persist_set_flags (persist, EMBED_PERSIST_NO_VIEW);
+	ephy_embed_persist_set_flags (persist, EPHY_EMBED_PERSIST_NO_VIEW);
 	ephy_embed_persist_set_source (persist, location);
 
 	g_signal_connect (persist, "completed",
@@ -360,12 +373,111 @@ popup_cmd_open_frame (GtkAction *action,
 	g_free (location);
 }
 
+static void
+image_open_uri (const char *address,
+		gboolean delete)
+{
+	GList *uris = NULL;
+	char *canonical;
+	GnomeVFSMimeApplication *app = NULL;
+	GnomeVFSFileInfo *info;
+
+	canonical = gnome_vfs_make_uri_canonical (address);
+
+	info = gnome_vfs_file_info_new ();
+	if (gnome_vfs_get_file_info (canonical, info,
+				     GNOME_VFS_FILE_INFO_GET_MIME_TYPE |
+				     GNOME_VFS_FILE_INFO_FORCE_SLOW_MIME_TYPE) == GNOME_VFS_OK &&
+	    (info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE) &&
+	    info->mime_type != NULL &&
+	    info->mime_type[0] != '\0' &&
+	    ephy_file_check_mime (info->mime_type) == EPHY_MIME_PERMISSION_SAFE)
+	{
+		app = gnome_vfs_mime_get_default_application (info->mime_type);
+	}
+
+	if (app != NULL)
+	{
+		/* FIXME rename tmp file to right extension ? */
+		uris = g_list_append (uris, canonical);
+		gnome_vfs_mime_application_launch (app, uris);
+		gnome_vfs_mime_application_free (app);
+		g_list_free (uris);
+		if (delete)
+		{
+			ephy_file_delete_on_exit (address);
+		}
+	}
+	else
+	{
+		/* FIXME We should really warn the user here */
+
+		g_warning ("Cannot find an application to open %s with.", address);
+		if (delete)
+		{
+			gnome_vfs_unlink (address);
+		}
+	}
+
+	g_free (canonical);
+	gnome_vfs_file_info_unref (info);
+}
+
+static void
+save_source_completed_cb (EphyEmbedPersist *persist)
+{
+	const char *dest;
+
+	dest = ephy_embed_persist_get_dest (persist);
+	g_return_if_fail (dest != NULL);
+
+	image_open_uri (dest, TRUE);
+}
+
+static void
+save_temp_source (const char *address)
+{
+	char *tmp, *base;
+	EphyEmbedPersist *persist;
+	const char *static_temp_dir;
+
+	static_temp_dir = ephy_file_tmp_dir ();
+	if (static_temp_dir == NULL)
+	{
+		return;
+	}
+
+	base = g_build_filename (static_temp_dir, "viewimageXXXXXX", NULL);
+	tmp = ephy_file_tmp_filename (base, "tmp"); /* FIXME */
+	g_free (base);
+	if (tmp == NULL)
+	{
+		return;
+	}
+
+	persist = EPHY_EMBED_PERSIST
+		(ephy_embed_factory_new_object (EPHY_TYPE_EMBED_PERSIST));
+
+	ephy_embed_persist_set_source (persist, address);
+	ephy_embed_persist_set_flags (persist, EPHY_EMBED_PERSIST_NO_VIEW);
+	ephy_embed_persist_set_dest (persist, tmp);
+
+	g_signal_connect (persist, "completed",
+			  G_CALLBACK (save_source_completed_cb), NULL);
+
+	ephy_embed_persist_save (persist);
+	g_object_unref (persist);
+
+	g_free (tmp);
+}
+
 void
 popup_cmd_open_image (GtkAction *action,
 		      EphyWindow *window)
 {
 	EphyEmbedEvent *info;
-	const char *location;
+	const char *address;
+	char *scheme;
 	const GValue *value;
 	EphyEmbed *embed;
 
@@ -374,7 +486,18 @@ popup_cmd_open_image (GtkAction *action,
 
 	info = get_event_info (window);
 	ephy_embed_event_get_property (info, "image", &value);
-	location = g_value_get_string (value);
+	address = g_value_get_string (value);
 
-	ephy_embed_load_url (embed, location);
+	scheme = gnome_vfs_get_uri_scheme (address);
+
+	if (strcmp (scheme, "file") == 0)
+	{
+		image_open_uri (address, FALSE);
+	}
+	else
+	{
+		save_temp_source (address);
+	}
+
+	g_free (scheme);
 }
