@@ -1,4 +1,4 @@
-/*
+ /*
  *  Copyright (C) 200-2003 Marco Pesenti Gritti
  *  Copyright (C) 2003, 2004 Christian Persch
  *
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: prefs-dialog.c,v 1.98 2004/11/25 14:45:12 chpe Exp $
+ *  $Id: prefs-dialog.c,v 1.106 2005/01/08 16:32:09 chpe Exp $
  */
 
 #include "config.h"
@@ -56,6 +56,7 @@
 #include <gtk/gtkimage.h>
 #include <gtk/gtklabel.h>
 #include <gtk/gtkstock.h>
+#include <gtk/gtknotebook.h>
 #include <string.h>
 
 #define CONF_FONTS_FOR_LANGUAGE	"/apps/epiphany/dialogs/preferences_font_language"
@@ -117,7 +118,6 @@ static const char *languages[] =
 	"be",
 	"bg",
 	"bn",
-	"bs",
 	"br",
 	"bs",
 	"ca",
@@ -278,7 +278,7 @@ struct
 }
 languages [] =
 {
-	{ "ak",		N_("Afrikaans") },
+	{ "af",		N_("Afrikaans") },
 	{ "ar",		N_("Arabic") },
 	{ "az",		N_("Azerbaijani") },
 	{ "be",		N_("Byelorussian") },
@@ -298,7 +298,7 @@ languages [] =
 	{ "fo",		N_("Faeroese") },
 	{ "fr",		N_("French") },
 	{ "ga",		N_("Irish") },
-	{ "gd",		N_("Scottish") },
+	{ "gd",		N_("Scots Gaelic") },
 	{ "gl",		N_("Galician") },
 	{ "he",		N_("Hebrew") },
 	{ "hr",		N_("Croatian") },
@@ -518,6 +518,9 @@ struct PrefsDialogPrivate
 #endif
 };
 
+/* gtk+' gettext domain */
+#define GTK_DOMAIN "gtk20"
+
 static GObjectClass *parent_class = NULL;
 
 GType
@@ -737,7 +740,7 @@ create_fonts_language_menu (EphyDialog *dialog)
 	{
 		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter,
-				    COL_FONTS_LANG_NAME, _(fonts_languages[i].title),
+				    COL_FONTS_LANG_NAME, Q_(fonts_languages[i].title),
 				    COL_FONTS_LANG_CODE, fonts_languages[i].code,
 				    -1);
 	}
@@ -1004,7 +1007,9 @@ get_name_for_lang_code (PrefsDialog *pd,
 
 		if (localename != NULL)
 		{
-			/* translators: the first %s is the language name, and the
+			/* Translators: The text before the "|" is context to help you decide on
+			 * the correct translation. You MUST OMIT it in the translated string.
+			 * Translators: the first %s is the language name, and the
 			 * second %s is the locale name. Example:
 			 * "French (France)"
 			 */
@@ -1014,13 +1019,17 @@ get_name_for_lang_code (PrefsDialog *pd,
 		}
 		else
 		{
+			/* Translators: The text before the "|" is context to help you decide on
+			 * the correct translation. You MUST OMIT it in the translated string. */
 			name = g_strdup_printf (Q_("language|%s (%s)"),
 						dgettext (ISO_639_DOMAIN, langname), str[1]);
 		}
 	}
 	else
 	{
-		/* translators: this refers to a user-define language code
+		/* Translators: The text before the "|" is context to help you decide on
+		 * the correct translation. You MUST OMIT it in the translated string.
+		 * Translators: this refers to a user-define language code
 		 * (one which isn't in our built-in list).
 		 */
 		name = g_strdup_printf (Q_("language|User defined (%s)"), code);
@@ -1429,24 +1438,17 @@ get_download_button_label ()
 
 	if (key == NULL || g_utf8_collate (key, "~") == 0)
 	{
-		/* Note that this does NOT refer to the home page but to a
-		 * user's home folder. It should be translated by the same
-		 * term as GTK+'s "Home" string to be consistent with the
-		 * filechooser */
-		label = g_strdup (_("Home"));
+		label = g_strdup (dgettext (GTK_DOMAIN, "Home"));
 	}
 	else if ((converted_dp != NULL && g_utf8_collate (key, converted_dp) == 0) ||
 		 g_utf8_collate (key, "Downloads") == 0)
 	{
 		label = g_strdup (_("Downloads"));
 	}
-	else if (g_utf8_collate (key, "~/Desktop") == 0)
+	else if (g_utf8_collate (key, "~/Desktop") == 0 ||
+	         g_utf8_collate (key, "Desktop") == 0)
 	{
-		label = g_strdup (_("Desktop")); 
-	}
-	else if (g_utf8_collate (key, "Desktop") == 0)
-	{
-		label = g_strdup (_("Desktop")); 
+		label = g_strdup (dgettext (GTK_DOMAIN, "Desktop"));
 	}
 	else
 	{
@@ -1499,11 +1501,6 @@ prefs_dialog_init (PrefsDialog *pd)
 	ephy_dialog_add_enum (dialog, properties[ACCEPT_COOKIES_PROP].id,
 			      n_cookies_accept_enum, cookies_accept_enum);
 
-	ephy_dialog_set_size_group (dialog,
-				    properties[DEFAULT_ENCODING_LABEL_PROP].id,
-				    properties[AUTO_ENCODING_LABEL_PROP].id,
-				    NULL);
-
 	ephy_dialog_get_controls
 		(dialog,
 		 properties[WINDOW_PROP].id, &window,
